/* builtin.h
 *
 * Copyright (C) 2002 Ron Coscorrosa
 *
 * This software is released under the terms of the GNU General Public License
 * (GNU GPL), see the file COPYING for details.
 *
 * This file contains all of the built-in L-systems.
 *
 */

#ifndef BUILTIN_H
#define BUILTIN_H

#include "util.h"
#include "constants.h"

/* Many of these L-systems were converted from Fractint files found at:
 *
 *  http://spanky.triumf.ca/pub/fractals/lsystems/
 *
 * Credit is given where it is known, specifically:
 *   William McWorter
 *   Gary Teachout
 *   Anthony Hanmer
 *   Ole Jorgensen
 *   Michael A. Rouse
 *   Jaume Bartroli
 *   Jos Torres
 *   Adrian Mariano
 *   Ken Philip
 *
 * Several other L-systems were taken from those given in the excellent book 
 * "The Computational Beauty of Nature" by Gary William Flake, see:
 *  http://mitpress.mit.edu/books/FLAOH/cbnhtml/
 * for more information.
 *
 * The rest were either well-known, easily derived, or original.
 *
 * See the "fractint2lsysexp.pl" script in the "doc" directory for a script
 * to convert from Fractint .L files to the format used in this file.
 *
 * Note: There are probably repeats in here!  If you find some let me know.
 * As of version 0.65 there are a total of 557 L-systems.
 */

/* These "cesaros" where done by Anthony Hanmer, if anyone wants to name them
 * something meaningful, don't let me get in your way! :) */
static lsys cesaros1 [] = 
   {
    {2, 10.5882352941176, 90, .50, "FX", "F = ;X = ++++F!X!--------F!X!++++", "Cesaro2"},
    {2, 90, 90, .50, "D\\90D\\90D\\90D\\90", "D = \\42!D!/84!D!\\42", "CesaroDouble"},
    {2, 8, 90, .50, "f", "f = f----------f++++++++++++++++++++f----------f", "Cesaro"},
    {2, 10, 90, .50, "f---------f---------f---------f", "f = f--------f++++++++++++++++f--------f", "b"},
    {2, 10, 90, .50, "f+++++++++f+++++++++f+++++++++f", "f = f--------f++++++++++++++++f--------f", "c"},
    {2, 90, 90, .50, "d", "d = d\\88d/176d\\88d", "e"},
    {2, 90, 90, .50, "d/90d/90d/90d", "d = d\\88d/176d\\88d", "e1"},
    {2, 90, 90, .50, "d\\90d\\90d\\90d", "d = d\\88d/176d\\88d", "e2"},
    {2, 90, 90, .50, "d\\90d\\90d\\90d/180d/90d/90d/90d", "d = d\\88d/176d\\88d", "e1a"},
    {2, 90, 90, .50, "d/90d/90d/90d", "d = d\\86d/176d\\90d", "e3"},
    {2, 90, 90, .50, "d/90d/90d/90d", "d = d\\45d/176d\\131d", "e4"},
    {2, 90, 90, .50, "d", "d = d\\90@.5d\\62d/178d\\52d/178d\\62d\\90@2d", "e5"},
    {2, 90, 90, .50, "d", "d = dd\\90d\\62d/178d\\52d/178d\\62d\\90dd", "e5a1"},
    {2, 90, 90, .50, "d", "d = ddd\\90dd\\62dd/178dd\\52dd/178dd\\62dd\\90ddd", "e5b"},
    {2, 90, 90, .50, "d", "d = dd\\90d\\82d/178d\\47d/178d\\47d\\90dd", "e5c"},
    {2, 90, 90, .50, "d\\90d\\90d\\90d", "d = dd\\90d\\88d/178d\\88d/178dd\\90dd", "e5d1"},
    {2, 90, 90, .50, "d\\90d\\90d\\90d/180d/90d/90d/90d", "d = dd\\90d\\88d/178d\\88d/178dd\\90dd", "e5d2"},
    {2, 90, 90, .50, "d\\90d\\90d\\90d", "d = dd\\90d\\88d/178d\\88d/178dd\\90d", "e5d3a"},
    {2, 90, 90, .50, "d\\90d\\90d\\90d/180d/90d/90d/90d", "d = dd\\90d\\88d/178d\\88d/178dd\\90d", "e5d3b"},
    {2, 90, 90, .50, "d/180d", "d = dd\\90d\\88d/178d\\88d/178dd\\90d", "e5d3c"},
    {2, 90, 90, .50, "d\\90d\\90d\\90d", "d = dd\\90d\\88d/178d\\88d/178d\\90dd", "e5d4a"},
    {2, 90, 90, .50, "d\\90d\\90d\\90d/180d/90d/90d/90d", "d = dd\\90d\\88d/178d\\88d/178d\\90dd", "e5d4b"},
    {2, 90, 90, .50, "d", "d = d\\90d\\88d/178d\\88d/178d\\90d", "e5d4c1"},
    {2, 90, 90, .50, "d\\90d\\90d\\90d", "d = d\\90d\\88d/178d\\88d/178d\\90d", "e5d4c2"},
    {2, 90, 90, .50, "d/90d/90d/90d", "d = d\\90d\\88d/178d\\88d/178d\\90d", "e5d4c3"},
    {2, 90, 90, .50, "ddd/90dd/90ddd/90dd", "d = d\\90d\\88d/178d\\88d/178d\\90d", "e5d4c4"},
    {2, 90, 90, .50, "d/90d/90d/90d", "d = dd\\90d\\88d/178d\\88d/178ddd", "e5d5"},

};



/* Same as above */
static lsys cesaros2 [] =
{

    {2, 90, 90, .50, "d\\90d\\90d\\90d", "d = d\\90@.5d\\62d/178d\\52d/178d\\62d\\90@2d", "e6"},
    {2, 90, 90, .50, "d\\72d\\72d\\72d\\72d", "d = d\\90@.5d\\62d/178d\\52d/178d\\62d\\90@2d", "e7"},
    {2, 90, 90, .50, "\\2d\\176d/86d\\176d/86d\\176d/86d\\176d", "d = d/88d\\176d/88d", "e8"},
    {2, 90, 90, .50, "d", "d = d/90d\\176d\\4d/90d", "e9a1"},
    {2, 90, 90, .50, "d\\90d\\90d\\90d", "d = d/90d\\176d\\4d/90d", "e9a2"},
    {2, 90, 90, .50, "d/90d/90d/90d", "d = d/90d\\176d\\4d/90d", "e9a3"},
        {2, 90, 90, .50, "d/90d/90d/90d", "d = d/90@.8d\\180@1.25d/90d", "f1"},
    {2, 90, 90, .50, "d\\90d\\90d\\90d/180d/90d/90d/90d", "d = d/90@.8d\\180@1.25d/90d", "f2"},
    {2, 90, 90, .50, "d\\90d\\90d\\90d", "d = d\\88d/176d\\88d\\88d/176d\\88d", "g1"},
    {2, 90, 90, .50, "d\\90d\\90d\\90d/180d/90d/90d/90d", "d = d\\88d/176d\\88d\\88d/176d\\88d", "g2"},
    {2, 90, 90, .50, "d\\90d\\90d\\90d", "d = dd\\88d\\88d/176dd/176d\\88d\\88dd", "h1"},
    {2, 90, 90, .50, "d\\90d\\90d\\90d/180d/90d/90d/90d", "d = dd\\88d\\88d/176dd/176d\\88d\\88dd", "h2"},
    {2, 90, 90, .50, "d", "d = ddd\\88dd\\88dd/176dddd/176dd\\88dd\\88ddd", "h3"},
    {2, 90, 90, .50, "d\\90d\\90d\\90d", "d = dd\\88d\\88d/176d\\88d/176d\\88d/176d\\88d\\88dd", "i1"},
    {2, 90, 90, .50, "d\\90d\\90d\\90d/180d/90d/90d/90d", "d = dd\\88d\\88d/176d\\88d/176d\\88d/176d\\88d\\88dd", "i2"},
    {2, 90, 90, .50, "d\\90d\\90d\\90d", "d = ddd\\88dd\\88dd/176dd\\88dd/176dd\\88dd/176dd\\88dd\\88ddd", "i3a"},
    {2, 90, 90, .50, "d\\90d\\90d\\90d/180d/90d/90d/90d", "d = ddd\\88dd\\88dd/176dd\\88dd/176dd\\88dd/176dd\\88dd\\88ddd", "i3b"},
    {2, 90, 90, .50, "d", "d = d/88d\\176dd/176d\\88d", "j"},
    {2, 90, 90, .50, "d", "d = d/88d\\176dddd/176d\\88d", "k1"},
    {2, 90, 90, .50, "d\\90d\\90d\\90d", "d = d/88d\\176dddd/176d\\88d", "k2"},
    {2, 90, 90, .50, "d", "d = d/88d\\176ddd/176d\\88d", "l1"},
    {2, 90, 90, .50, "d\\90d\\90d\\90d", "d = d/88d\\176ddd/176d\\88d", "l2"},
    {2, 90, 90, .50, "d\\90d\\90d\\90d", "d = dd\\88d\\88d/176d\\88dd/176d\\88d/176d\\88dd\\88dd", "m1"},
    {2, 90, 90, .50, "d\\90d\\90d\\90d/180d/90d/90d/90d", "d = dd\\88d\\88d/176d\\88dd/176d\\88d/176d\\88dd\\88dd", "m2"},
    {2, 90, 90, .50, "d\\90d\\90d\\90d", "d = ddd\\88d\\88d/176d\\88dd/176d\\88d/176d\\88dd\\88ddd", "n1"},
    {2, 90, 90, .50, "d\\90d\\90d\\90d/180d/90d/90d/90d", "d = ddd\\88d\\88d/176d\\88dd/176d\\88d/176d\\88dd\\88ddd", "n2"}
};



/* Curves, which are continuous */
static lsys curves [] = 
{
    {2, 90, 90, .50, "F+F+F+F+", "f = FF+F+F+F+F+F-F", "Curve1"},
    {2, 90, 90, .50, "F+F+F+F+", "f = FF+F-F+F+FF", "Curve2"},
    {2, 60, 90, .50, "yf", "x = YF-XF-Y;y = XF+YF+X", "Curve4"},
    {2, 30, 90, .50, "FR", "F = ;R = --!FRFU--FU--FU!+++@Q3FU|+@IQ3!FRFU!;U = !FRFU!|-@Q3FR@IQ3---!FR++FR++FRFU!++", "SnowFlake1"},
    {2, 30, 90, .50, "F", "F = --!F!F++F++F@IQ3|-F!F++F++F!---@Q3F@QI3|-F!F@Q3|-F!F", "SnowFlake2"},
    {2, 30, 90, .50, "fx", "f = ;x = --f!x!fy++fx++fy|-@iq3fyf!x!--f!y!--f!y!fx@q3---f!y!fx;y = fyf!x!---@iq3fyf!x!--f!x!--f!y!fx@q3|-fx++fy++fxf!y!--", "SnowFlake3"},

    /* By Gary Teachout */
    {2, 30, 90, .50, "x", "x = \\38@0.788010dx@i0.788010/90@0.615661da@i0.615661\\52;a = dx;d = ", "c_curve_sl_38"},
    {2, 30, 90, .50, "x", "e = dx;x = \\32@0.848048dx@i0.848048/90@0.529919da@i0.529919\\58;a = db;b = de;d = ", "c_curve_sl_32"},
    {2, 30, 90, .50, "x", "n = dx;a = db;b = de;d = ;e = dh;x = \\25@0.906308dx@i0.906308/90@0.422618da@i0.422618\\65;h = dj;j = dk;k = dl;l = dn", "c_curve_sl_25"},
    {2, 45, 90, .50, "f", "f = +f--f+", "c_curve_1"},
    {2, 45, 90, .50, "f", "f = +@1.5f@i1.5--f+", "c_curve_2"},
    
    /* By Ole Jorgensen */
    {2, 90, 90, .50, "f", "f = -f+f", "Boat"},

    /* By William McWorter */
    {2, 30, 90, .50, "r", "f = -f++f[++++f]-;r = f", "TrainSmoke"}
};



/* First half of L-systems found in "fractint.l" */
static lsys fractint1 [] = 
   {
    {2, 60, 90, .50, "F++F++F", "F = F-F++F-F", "Koch1"},
    {2, 30, 90, .50, "F+++F+++F+++F", "F = +F---F+++F-", "Koch2"},
    {2, 90, 90, .50, "F+F+F+F", "F = F+F-F-FF+F+F-F", "Koch3"},
    {2, 90, 90, .50, "f-f-f-f", "f = f+ff-ff-f-f+f+ff-f-f+f+ff+ff-f", "Koch6"},
    {2, 45, 90, .50, "FX", "F = ;x = +FX--FY+;y = -FX++FY-", "Dragon"},
    {2, 90, 90, .50, "F+F+F+F", "F = F+F-F-F-F+F+F+F-F", "Peano1"},
    {2, 10.5882352941176, 90, .50, "FX", "F = ;X = ++++F!X!--------F!X!++++", "Cesaro"},
    {2, 90, 90, .50, "D\\90D\\90D\\90D\\90", "D = \\42!D!/84!D!\\42", "DoubleCesaro"},
    {2, 60, 90, .50, "FL", "F = ;R = -FL+FRFR++FR+FL--FL-FR;L = FL+FR++FR-FL--FLFL-FR+", "FlowSnake"},
    {2, 60, 90, .50, "F", "F = FGF;G = GGG", "CantorDust"},
    {2, 30, 90, .50, "F", "F = --!F!F++F++F@IQ3|-F!F++F++F!---@Q3F@QI3|-F!F@Q3|-F!F", "Snowflake2"},
    {2, 90, 90, .50, "F-F-F-F", "F = FFFF+F-F-F+F[+GFF-F-FF-F]FF;G = @8G@I8", "Island1"},
    {2, 90, 90, .50, "f-f-f-f", "f = f-gf+ff+f+ff-g-ff+gf-ff-f-ff+g+fff;g = @6G@I6", "Island2"},
    {2, 90, 90, .50, "fb", "F = ;H = +;A = FBFA-HFA-FB+FA;J = -;B = FB-FA+FB+JFBFA", "Quartet"},
    {2, 30, 90, .50, "FR", "F = ;R = --!FRFU--FU--FU!+++@Q3FU|+@IQ3!FRFU!;U = !FRFU!|-@Q3FR@IQ3---!FR++FR++FRFU!++", "SnowFlake1"},
    {2, 30, 90, .50, "fx", "f = ;x = --f!x!fy++fx++fy|-@iq3fyf!x!--f!y!--f!y!fx@q3---f!y!fx;y = fyf!x!---@iq3fyf!x!--f!x!--f!y!fx@q3|-fx++fy++fxf!y!--", "SnowFlake3"},
    {2, 30, 90, .50, "---FX", "X = @.6[+FX]-FX", "Tree1"},
    {2, 45, 90, .50, "FXY--F--FXY--F", "X = XY@Q2+F@IQ2+FXY--F--FXY;Y = +@Q2F+@IQ2FXY", "Peano2"},
    {2, 120, 90, .50, "F", "F = FXF;X = -FXF+FXF+FXF-", "Sierpinski1"},
    {2, 30, 90, .50, "f----f----f", "f = -f++f--f+", "Koch4"},
    {2, 25.7142857142857, 0, .50, "Z", "x = x[+FFF][-FFF]FX;z = zFX[-Z][+Z]", "Plant07"},
    {2, 18, 0, .50, "SLFFF", "h = +Z[-H]L;z = -H[+Z]L;s = [---Z][+++Z]TS;l = [+FFF][-FFF]F;t = TL", "Plant08"},
    {2, 90, 90, .50, "x", "x = +YF-XFX-FY+;y = -XF+YFY+FX-", "Hilbert"},
    {2, 120, 90, .50, "F+F+F", "f = F[+F]F", "Sierpinski3"},
    {2, 90, 90, .50, "x", "x = XFYFX-F-YFXFY+F+XFYFX;y = YFXFY+F+XFYFX-F-YFXFY", "Peano3"},
    {2, 90, 90, .50, "f-F-F-F", "f = F-F+F+FFF-F-F+F", "Koch5"},
    {2, 60, 90, .50, "FXF++FF++FF", "f = FF;x = ++FXF--FXF--FXF++", "Sierpinski2"},
    {2, 90, 90, .50, "F-F-F-F", "f = FF-F-F-F-FF", "SierpinskiSquare"},
    {2, 36, 90, .50, "fx--fx--fx--fx--fx", "x = [----@i1.618033989f@.618033989f!x!@i.618033989f]", "Pentagram"},
    {2, 90, 90, .50, "F+F+F+F+", "F = F-FF+FF+F+F-F-FF+F+F-F-FF-FF+F", "QuadKoch"},
    {2, 90, 90, .50, "+l", "R = +LFLF-RFRFR-F-RF+LFL+FR;L = LF-RFR-FL+F+LFLFL+FRFR-", "Fass1"},
    {2, 90, 90, .50, "+l", "R = +LFLFLF-RFR-FL+F+LF-RFR-FLF-RFRF+LFL+FRFR;L = LFLF-RFR-FLFL+FRF+LFL+FR-F-RF+LFL+FRFRFR-", "Fass2"},
    {2, 90, 90, .50, "+Fr", "f = ;r = -FlFl+Fr+Fr-Fl-FlFr-Fl+FrFr+Fl+Fr-FlFrFr+Fl+FrFl-Fl-Fr+Fr+Fl-Fl-FrFr;l = FlFl+Fr+Fr-Fl-Fl+Fr+FrFl-Fr-FlFlFr+Fl-Fr-FlFl-Fr+FlFr+Fr+Fl-Fl-FrFr+", "QuadGosper"}

};



/* Second half of L-systems found in "fractint.l" */
static lsys fractint2 [] =
{
    {2, 25.7142857142857, 0, .50, "f", "f = F[-F]F[+F]F", "Plant01"},
    {2, 20, 0, .50, "f", "f = F[-F]F[+F][F]", "Plant02"},
    {2, 22.5, 0, .50, "f", "f = FF+[+F-F-F]-[-F+F+F]", "Plant03"},
    {2, 20, 0, .50, "x", "F = FF;X = F[-X]F[+X]-X", "Plant04"},
    {2, 25.7142857142857, 0, .50, "x", "F = FF;X = f[-X][+X]FX", "Plant05"},
    {2, 22.5, 0, .50, "x", "F = FF;X = F+[[X]-X]-F[-FX]+X", "Plant06"},
    {2, 25.7142857142857, 0, .50, "y", "x = X[+FFF][-FFF]FX;y = YFX[-Y][+Y]", "Plant09"},
    {2, 36, 0, .50, "f", "f = f[-ff][+ff]f[-ff][+ff]f", "Plant10"},
    {2, 30, 0, .50, "f", "f = F[-F[-F][+F]F][+F[-F][+F]F]F[-F][+F]F", "Plant11"},
    {2, 90, 90, .50, "F+F+F+F+", "f = FF+F+F+F+F+F-F", "Curve1"},
    {2, 90, 90, .50, "F+F+F+F+", "f = FF+F-F+F+FF", "Curve2"},
    {2, 90, 90, .50, "F+F+F+F+", "F = F+FF++F+F", "Curve3"},
    {2, 60, 90, .50, "yf", "x = YF-XF-Y;y = XF+YF+X", "Curve4"},
    {2, 45, 90, .50, "x", "F = @1.18F@i1.18;e = h;n = o;o = p;x = F[-A(4)]Fy;h = j;p = x;y = F[+B(4)]Fx;a = n;j = y;b = e", "Leaf1"},
    {2, 45, 90, .50, "a", "f = @1.36f@i1.36;x = a;y = b;a = f[-x]fb;b = f[+y]fa", "Leaf2"},
    {2, 22.5, 90, .50, "----F", "F = FF+[+F-F-F]-[-F+F+F]", "Bush"},
    {2, 22.5, 90, .50, "----F", "F = FF+[XY]-[XY];X = -FY;Y = +FX", "MyTree"},
    {2, 60, 90, .50, "++X", "F = FF;X = --FXF--FXF--FXF", "ColorTriangGasket"},
    {2, 90, 90, .50, "X", "F = FF;X = -FXF-FXF-FXF-FXF", "SquareGasket"},
    {2, 90, 90, .50, "X", "X = X+YF+;Y = -FX-Y", "DragonCurve"},
    {2, 90, 90, .50, "F-F-F-F", "F = FF-F-F-F-FF", "Square"},
    {2, 60, 90, .50, "F", "F = F-F++F-F", "KochCurve"},
    {2, 36, 90, .50, "-WF++XF+++YF++ZF", "F = ;W = YF--ZF++++XF[+YF++++WF]--;X = -YF++ZF[+++WF++XF]-;Y = +WF--XF[---YF--ZF]+;Z = ++YF----WF[-ZF----XF]++XF", "Penrose1"},
    {2, 36, 90, .50, "-WF++XF+++YF++ZF", "F = ;W = YF--ZF++++XF[+YF++++WF]--;X = -YF++ZF[+++WF++XF]-;Y = +WF--XF[---YF--ZF]+;Z = ++YF----WF[-ZF----XF]++XF", "ColorPenrose1"},
    {2, 36, 90, .50, "--ZF++++XF+YF++++WF", "F = ;W = YF--ZF++++XF[+YF++++WF]--;X = -YF++ZF[+++WF++XF]-;Y = +WF--XF[---YF--ZF]+;Z = ++YF----WF[-ZF----XF]++XF", "Penrose2"},
    {2, 36, 90, .50, "[X]--[X]--[X]--[X]--[X]", "F = ;W = YF--ZF++++XF[+YF++++WF]--;X = -YF++ZF[+++WF++XF]-;Y = +WF--XF[---YF--ZF]+;Z = ++YF----WF[-ZF----XF]++XF", "Penrose3"},
    {2, 36, 90, .50, "[Y]--[Y]--[Y]--[Y]--[Y]", "F = ;W = YF--ZF++++XF[+YF++++WF]--;X = -YF++ZF[+++WF++XF]-;Y = +WF--XF[---YF--ZF]+;Z = ++YF----WF[-ZF----XF]++XF", "Penrose4"},
    {2, 36, 90, .50, "[X][Y]--[X][Y]--[X][Y]--[X][Y]--[X][Y]", "F = ;W = YF--ZF++++XF[+YF++++WF]--;X = -YF++ZF[+++WF++XF]-;Y = +WF--XF[---YF--ZF]+;Z = ++YF----WF[-ZF----XF]++XF", "DoublePenrose"},
    {2, 36, 90, .50, "F--F--F--F--F", "F = F--F--F|F+F--F", "PentaPlexity"},
    {2, 15, 90, .50, "X-X-X-X-X-X-X-X-X-X-X-X-X-X-X-X-X-X-X-X-X-X-X-X", "x = [F-F-F-F[+++X+Y]-----F--------F+F+F+F];y = [F-F-F-F[+++Y]-----F--------F+F+F+F]", "CircularTile"}
};


/* Sierpinski's and related */
static lsys gaskets [] = 
{
    {2, 60, 90, .50, "++X", "F = FF;X = --FXF--FXF--FXF", "ColorTriangGasket"},
    {2, 90, 90, .50, "F-F-F-F", "F = FFFF+F-F-F+F[+GFF-F-FF-F]FF;G = @8G@I8", "Island1"},
    {2, 90, 90, .50, "f-f-f-f", "f = f-gf+ff+f+ff-g-ff+gf-ff-f-ff+g+fff;g = @6G@I6", "Island2"},
    {2, 120, 90, .50, "F", "F = FXF;X = -FXF+FXF+FXF-", "Sierpinski1"},
    {2, 60, 90, .50, "FXF++FF++FF", "f = FF;x = ++FXF--FXF--FXF++", "Sierpinski2"},
    {2, 120, 90, .50, "F+F+F", "f = F[+F]F", "Sierpinski3"},
    {2, 90, 90, .50, "F-F-F-F", "F = FF-F-F-F-FF", "SierpinskiSquare"},
    {2, 90, 90, .50, "X", "F = FF;X = -FXF-FXF-FXF-FXF", "SquareGasket"},

    /* By William McWorter */
    {2, 45, 90, .50, "L", "R = +L-F-L+;L = -R+F+R-", "Sierpinsk"},
    {2, 45, 90, .50, "L++F++L++F", "R = +L-F-L+;L = -R+F+R-", "Sierpinski"},
    {2, 45, 90, .50, "z", "f = ;g = ;w = fw;x = -[+@.5g--@2.414g|@q2f++f+++@q2f]y+fw+[+@.5g--@2.414g|@q2f++f+++@q2f]y-;y = +[-@.5g++@2.414g|@q2f--f---@q2f]x-fw-[-@.5g++@2.414g|@q2f--f---@q2f]x+;z = x", "Sierpinski1"},
    {2, 90, 90, .50, "f", "f = f-f+f+f+g-f-f-f+f;g = ggg", "SierpinskiCarpet"},

    /* By Michael A. Rouse */
    {2, 60, 90, .50, "F-F-F-F-F-F++", "F = F-F-F++F++F-F-F", "HexGasket"},

    /* From The Computational Beauty of Nature */
    {2, 90, 0, .5, "f-f-f-f", "f = f[f]-f+f[--f]+f-f", "Carpet"},
    {2, 90, 0, .5, "f-f-f-f", "f = ff[-f-f-f]f", "Sierpinski Square"},
    {2, 90, 0, .5, "f-f-f-f", "f = f[-f-f]ff", "Rug"},
    {2, 60, 270, .5, "f", "f = [gf][+g3-f][g+g+f];g = gg", "Sierpinski Maze"},
    {2, 60, 90, .5, "f", "f = [-g3+f][-g+f][gg--f];g = gg", "Sierpinski Arrowhead"},

    /* By Ron Coscorrosa */
    {2, 60, 90, .5, "f--f--f", "f=fgggf;g=ff--ff", "Sierpinski Dash"},
    {2, 60, 90, .5, "f--f--f", "f=fgggf;g=f--f++f--f", "Sierpinski T-Shirt"},
    {2, 120, 90, .5, "gf-gf-gf", "f=gf[-f]fg", "Sierpinski Blotch"},

    /* New in version 0.65 */
    {2, 90, 90, .50, "d", "r = \\80;d = d[/10ld\\10rd\\10rd]\\10rd/10ld/10ld\\10rd;l = /80", "Sierpinskicarpet10"},
    {2, 90, 90, .50, "d", "r = \\45;d = d[/45ld\\45rd\\45rd]\\45rd/45ld/45ld\\45rd;l = /45", "Sierpinskicarpet45"},
    {2, 90, 90, .50, "d", "r = \\30;d = d[/60ld\\60rd\\60rd]\\60rd/60ld/60ld\\60rd;l = /30", "Sierpinskicarpet60"},
    {2, 90, 90, .50, "d", "r = \\10;d = d[/80ld\\80rd\\80rd]\\80rd/80ld/80ld\\80rd;l = /10", "Sierpinskicarpet80"},
    {2, 90, 90, .50, "d", "r = ;d = d[/90ld\\90rd\\90rd]\\90rd/90ld/90ld\\90rd;l = ", "Sierpinskicarpet90"}
};



/* By Jaume Bartroli, from or inspired by "Chaos ans Fractals" by Peitgen,
 * Jrgens and Saupe */
static lsys sqplants [] = 
{
    {2, 45, 90, .50, "F--F[A]--F[B]--F", "A = +@IQ2F[A]--F[B]--F--F;B = +++@IQ2F--F[A]--F[B]--F", "PT1"},
    {2, 30, 90, .50, "F---F[A]---F[B]---F", "A = ++@.5F[A]---F[B]---F---F;B = +++++@.866F---F[A]---F[B]---F", "PT2"},
    {2, 30, 90, .50, "F---F[A]---F[B]---F", "P = +@.866F[A]---F[B]---F---F;Q = ++++@.5F---F[A]---F[B]---F;A = ++@.5F[P]---F[Q]---F---F;B = +++++@.866F---F[P]---F[Q]---F", "PT3"},
    {2, 120, 90, .50, "D\\90D[A]\\90D[B]\\90D", "A = /20@.532D[A]\\90D[B]\\90D\\90D;B = /160@.532D\\90D[A]\\90D[B]\\90D", "PT4"},
    {2, 120, 90, .50, "D\\90D[A]\\90D[B]\\90D", "A = /53.13@.6D[A]\\90D[B]\\90D\\90D;B = /143.13@.8D\\90D[A]\\90D[B]\\90D", "PT5"},
    {2, 120, 90, .50, "D\\90D[A]\\90D[B]\\90D", "P = /36.87@.8D[A]\\90D[B]\\90D\\90D;Q = /126.87@.6D\\90D[A]\\90D[B]\\90D;A = /53.13@.6D[P]\\90D[Q]\\90D\\90D;B = /143.13@.8D\\90D[P]\\90D[Q]\\90D", "PT6"},
    {2, 120, 90, .50, "D\\90D[A]\\90D[B]\\90D", "A = /67.38@.3846D[A]\\90D[B]\\90D\\90D;B = /157.38@.9231D\\90D[A]\\90D[B]\\90D", "PT7"},
    {2, 120, 90, .50, "D\\90D[A]\\90D[B]\\90D", "A = /50@.643D[A]\\90D[B]\\90D\\90D;B = /140@.766D\\90D[A]\\90D[B]\\90D", "PT8"},
    {2, 30, 90, .50, "F---FF[A]---F[B]---FF", "A = ++@.5FF[A]---F[B]---FF---F;B = +++++@.866F---FF[A]---F[B]---FF", "PT9"},
    {2, 120, 90, .50, "DD\\90D[A]\\90DD[B]\\90D", "A = /20@.532D[A]\\90DD[B]\\90D\\90DD;B = /160@.532DD\\90D[A]\\90DD[B]\\90D", "PT10"},
    {2, 30, 90, .50, "F---F[A]---F[B]---F", "P = +@.866F[A]---F[B]---F---F;Q = ++++@.5F---F[A]---F[B]---F;A = ++@.5F[P]---F[Q]---F---F;B = +++++@.866F---F[A]---F[B]---F", "PT11"},
    {2, 30, 90, .50, "F---F[A]---F[B]---F", "P = +@.866F[A]---F[B]---F---F;Q = ++++@.5F---F[A]---F[B]---F;A = ++@.5F[A]---F[B]---F---F;B = +++++@.866F---F[P]---F[Q]---F", "PT12"},
    {2, 30, 90, .50, "F---F[A]---G[B]---F", "A = ++@.5F[A]---G[B]---F---G;B = +++++@.866G---F[A]---G[B]---F", "PT13"},
    {2, 30, 90, .50, "F---FF[A]---G[B]---FF", "A = ++@.5FF[A]---G[B]---FF---G;B = +++++@.866G---FF[A]---G[B]---FF", "PT14"},
    {2, 30, 90, .50, "F---F[A]---G[B]---F", "P = +@.866F[A]---G[B]---F---G;Q = ++++@.5G---F[A]---G[B]---F;A = ++@.5F[P]---G[Q]---F---G;B = +++++@.866G---F[P]---G[Q]---F", "PT15"},
    {2, 120, 90, .50, "D\\90D[A]\\90M[B]\\90D", "A = /20@.532D[A]\\90M[B]\\90D\\90M;B = /160@.532M\\90D[A]\\90M[B]\\90D", "PT16"}
};



/* Misc. L-systems, part 1 */
static lsys misc1 [] = 
   {
    /* by William McWorter */
    {2, 90, 90, .50, "XYXYXYX-XYXYXYX-XYXYXYX-XYXYXYX", "F = ;X = FX-FX-FXFY+FY+;Y = -FX-FXFY+FY+FY", "Border1"},
    {2, 30, 90, .50, "f++f++f++f++f++f", "f = +f[++f++f]--f++f-", "Doily"},
    {2, 90, 90, .50, "YXY+YXY+YXY+YXY", "F = ;X = FX-FX-FXFYFX-FXFY+FY+FY+;Y = -FX-FX-FXFY+FYFXFY+FY+FY", "Frame"},
    {2, 120, 90, .50, "f-f-f", "f = f-ff+f", "Maze01"},
    {2, 120, 90, .50, "x", "f = ;x = fy-fyfy+fy;y = fx+fxfx-fx", "MazeFractal1"},
    {2, 90, 90, .50, "X", "F = ;X = FX-FX-FXFYFX-FXFY+FY+FY+;Y = -FX-FX-FXFY+FYFXFY+FY+FY", "Moore"},
    {2, 60, 90, .50, "f", "f = +f-f-g[-f-f]+;g = gg", "Hex"},
    {2, 60, 90, .50, "f", "f = +f-f-f[-f-f-f]+", "Hex1"},
    {2, 36, 90, .50, "w", "f = ;w = --[+@1.618033989f@I1.618033989----f]fx++[--@1.618033989f++++f]fw++[++@1.618033989f----f]fy--;x = +[-@1.618033989f@I1.618033989++++f]fz--[++@1.618033989f----f]fy+;y = ++[-@1.618033989f@I1.6180339898++++f]fz--[++@1.618033989f----f]fy--[--@1.618033989f++++f]fw++;z = -[+@1.618033989f@I1.618033989----f]fx++[--@1.618033989f++++f]fw-", "Isocepent"},
    {2, 45, 90, .50, "x", "x = -y+f+y-;y = +x-f-x+", "isocright"},
    {2, 72, 90, .50, "x+x+x+x+x", "f = ;x = fx+fx+fx-fy-fy-fx+fx;y = fy-fy+fx+fx+fy-fy-fy", "Pentant"},
    {2, 36, 90, .50, "F--F--F--F--F", "F = F--F--F|F+F--F", "PentaPlexity_0"},
    {2, 72, 90, .50, "F+F+F+F+F", "F = F+F--F-F+F+F", "Pentigree"},
    {2, 36, 90, .50, "W", "F = ;W = --FX++FW++FY--;X = +FZ--FY+;Y = ++FZ--FY--FW++;Z = -FX++FW-", "Pentive"},
    {2, 30, 90, .50, "---fw++++fzfw-", "f = ;w = +++fy----fxfy+;x = -fzfw++++fz---;y = ---fw++++fzfw-;z = +fxfy----fx+++", "PreLace"},
    {2, 36, 90, .50, "u", "F = G;u = @.381966[v]F[|y][+u]--F|-[v]F[|y]--F|-[v]F[|y]--F|-[v]F[|y]--F|-[v]F[|y]--F;v = @.381966[v]F[|y]--F|-[v]F[|y]+[u]F+F|-[v]F[|y]--F;w = @.381966G--[u]F|-F+F|-[v]F[|y];x = @.381966G--G--[!x][!z]F++[!z]F++[!z]F++[!z]F++[!z]F;y = @.381966[x][y][w]F[|!y]--F--[y][w]F[|!y]--F--[z]F;z = @.381966[z][x]F--[z]F--[w][y]F[|!y]--F--[z]F", "StarsPentas2"},
    {2, 90, 90, .50, "UW", "V = --F++W--F++Z;F = ;W = --F++W+F-X;X = FUFY;Y = -F+VFY;Z = +F-X++F--Z;U = FU-F+V", "Strike_S"},
    {2, 36, 90, .50, "r", "f = ;p = fp;x = fx--fy++fx++fx++fx-fy---;y = +++fx+fy--fy--fy--fx++fy;r = x", "Sextet"},
    {2, 36, 90, .50, "r", "n = --g|fz----fw++fo-;o = ++g|fx++++fy--fn+;p = -fw++fo-;q = +ft--fp++++fu|g++;r = x;s = +fy--fn+;t = -fq++fs----fv|g--;u = fq++fs----fv++;f = ;v = ft--fp++++fu--;g = -g++g-;w = +ft--fp+;x = ++fz----fw++fo;y = -fq++fs-;z = --fx++++fy--fn", "Pentive4"},
};



/* Misc. L-systems, part 2 */
static lsys misc2 [] =
{
    {2, 60, 90, .50, "F", "F = FGF;G = GGG", "CantorDust"},
    {2, 36, 90, .50, "fx--fx--fx--fx--fx", "x = [----@i1.618033989f@.618033989f!x!@i.618033989f]", "Pentagram"},
    {2, 60, 90, .50, "X", "F = GG;G = GG;X = -FF+YFF-FF++FFF|X|F++YFFFYFFF|;Y = +FF-XFF+FF--FFF|Y|F--XFFFXFFF|", "Sphinx"},
    
    /* By Dekking */
    {2, 90, 90, .50, "WZYX", "F = ;W = FW-F+XFW+F-Z;X = --F++Y+F-Z--F++Y+F-Z;Y = --F++Y-F+X;Z = FW-F+X", "Dekking"},
    {2, 51.4285714285714, 90, .50, "g-g-g-g-g-g-g", "f = ;g = [@.25f]g-[@.25f]g+++[@.25f]g+++[@.25f]g++", "Dekking3"},

    /* By Ole Jorgensen */
    {2, 90, 90, .50, "F-F-F-F", "F = +F-F", "Sporrer"},
    {2, 90, 90, .50, "F-F-F-F", "F = -F+F", "Sporrer2"},
    {2, 24, 90, .50, "|X", "F = FFFFF;X = F[s][t];s = ++++F[s][t]+F[s][t]+F[s][t]+F[s][t]+F[s][t]+F[s][t]+F[s][t]+F[s][t];t = ----F[s][t]-F[s][t]-F[s][t]-F[s][t]-F[s][t]-F[s][t]-F[s][t]-F[s][t]", "Cirkles"},

    /* By Jos Torres */
    {2, 51.4285714285714, 90, .50, "-[X]-[X]-[X]-[X]-[X]-[X]-[X]", "X = F+[@.4X]-[@.4X]-[@.4X]", "1heptagon"},
    {2, 60, 90, .50, "-[X]-[X]-[X]-[X]-[X]-[X]", "X = F+[@.4X]+[@.25X]--[@.4X]-[@.4X]-[@.25X]", "1Hexagon"},
    
    /* By William McWorter */
    {2, 60, 90, .50, "x", "f = ;p = fp;x = fx-fp-fx+fp+fx+fp+fxfpfpfx-fp-fx-fp-fx+fp+fxfpfpfx", "Maze09rnd"},
    {2, 60, 90, .50, "x", "x = x-f-x+f+x+f+xffx-f-x-f-x+f+xffx", "Maze09M"},
    {2, 90, 90, .50, "x", "f = ;x = fx+fy-fx+fy-fx-fx+fy-fx-fxfy+fy+fx-fy+;y = -fx+fy-fx-fxfy+fy+fx-fy+fy+fx-fy+fx-fy", "Maze08"},
    {2, 90, 90, .50, "x", "f = ;x = fxfy-fyfxfy-fyfx+fx+fxfyfx+fxfy-;y = +fxfy-fyfxfy-fy-fyfx+fxfyfx+fxfy", "Maze07"},
    {2, 60, 90, .50, "x", "f = ;p = fp;x = fx-fp-fxfpfpfx+fp+fx", "Maze01rnd"},
    {2, 60, 90, .50, "y", "x = x-f-xffx+f+x;y = x", "Maze01M"},
    {2, 90, 90, .50, "fx", "f = ;x = -fy-fyfx+fx+fxfyfx+fxfy-fy-fyfx+fx;y = fy-fyfx+fx+fxfy-fyfxfy-fy-fyfx+fx+", "Maze02"},

    /* From The Computational Beauty of Nature */
    {2, 90, 90, .667, "[f]--f", "f = %[+f][-f]", "Big H"},
    {2, 80, 90, .65, "[f]--f", "f = %[+f][-f]", "Bent Big H"},
    {2, 45, 90, .667, "[f]4-f", "f = %[+f][-f]", "Two Ys"},

    /* New in version 0.65 */
    {2, 90, 90, .50, "s", "h = @22f@i22;j = g-g+;k = @7g@i7;s = h-h-h-h-j[[@i3.66666667s]k[@i3.66666667s]k[@i3.66666667s]]-k+[[@i3.66666667s]k[@i3.66666667s]k[@i3.66666667s]]-k+[[@i3.66666667s]k[@i3.66666667s]k[@i3.66666667s]]", "Squared"},
    {2, 7.5, 90, .50, "------------ff+x", "x = -f[-------@0.65x][++++++++@0.65!x]+f[+++@0.6!x]--@.8f@1.25[----@0.45x]++f[+++@0.2!x]-[--@0.75!x]", "arbre"},
    {2, 90, 90, .50, "xxxx", "f = ff;x = f[y]+f;y = -ff[y]+ff[y]+ff[y]+ff", "carres"},
    {2, 36, 90, .50, "xxxxx", "f = ff;x = f[y]++f;y = @0.76---ff[y]++ff[y]++ff[y]++ff[y]++ff", "pentagones"}
};



/* Plants, 1/5 */
static lsys plants1 [] = 
   {
    {2, 22.5, 0, .50, "A", "f = ff;A = f+[A-A]-f[-fA]+A", "Alfonseca"},
    {2, 30, 0, .50, "t", "f = ff;r = f[++l][--l]f;s = @.5s;t = r-[t]++[++l]r[--l]+[t]--t;l = [s-f+f+f-|-f+f+f]", "Alfonseca1"},

    /* By Adrian Mariano, from the Algorithmic Beauty of Plants */
    {2, 22.5, 90, .50, "----F", "F = FF+[+F-F-F]-[-F+F+F]", "Bush"},
    {2, 45, 0, .50, "x", "F = @1.18F@i1.18;e = h;n = o;o = p;x = F[-A(4)]Fy;h = j;p = x;y = F[+B(4)]Fx;a = n;j = y;b = e", "Leaf1"},
    {2, 45, 0, .50, "a", "f = @1.36f@i1.36;x = a;y = b;a = f[-x]fb;b = f[+y]fa", "Leaf2"},
    {2, 22.5, 90, .50, "----F", "F = FF+[XY]-[XY];X = -FY;Y = +FX", "MyTree"},
    {2, 25.7142857142857, 0, .50, "f", "f = F[-F]F[+F]F", "Plant01"},
    {2, 20, 0, .50, "f", "f = F[-F]F[+F][F]", "Plant02"},
    {2, 22.5, 0, .50, "f", "f = FF+[+F-F-F]-[-F+F+F]", "Plant03"},
    {2, 20, 0, .50, "x", "F = FF;X = F[-X]F[+X]-X", "Plant04"},
    {2, 25.7142857142857, 0, .50, "x", "F = FF;X = f[-X][+X]FX", "Plant05"},
    {2, 22.5, 0, .50, "x", "F = FF;X = F+[[X]-X]-F[-FX]+X", "Plant06"},
    {2, 25.7142857142857, 0, .50, "y", "x = X[+FFF][-FFF]FX;y = YFX[-Y][+Y]", "Plant09"},
    {2, 36, 0, .50, "f", "f = f[-ff][+ff]f[-ff][+ff]f", "Plant10"},
    {2, 30, 0, .50, "f", "f = F[-F[-F][+F]F][+F[-F][+F]F]F[-F][+F]F", "Plant11"},
    {2, 30, 90, .50, "---FX", "X = @.6[+FX]-FX", "Tree1"},

    /* By Ken Philip, from the Science of Fractal Images, p. 285-286 */
    {2, 25.7142857142857, 90, .50, "Z", "x = x[+FFF][-FFF]FX;z = zFX[-Z][+Z]", "Plant07"},
    {2, 18, 90, .50, "SLFFF", "h = +Z[-H]L;z = -H[+Z]L;s = [---Z][+++Z]TS;l = [+FFF][-FFF]F;t = TL", "Plant08"},

    /* By William McWorter */
    {2, 7.2, 90, .50, "-------------x", "x = f[@.5---------x@.5f-------f++f|----f++++++f]+f[@.4+++++++++++!x@.5f-------f++f|----f++++++f]@.6x", "Leafy"},
    {2, 20, 90, .50, "x", "F = FF;X = F[-X]F[+X]-X", "Plant04"},
    {2, 7.2, 90, .50, "-------------x", "x = f[@.5---------x]+f[@.4+++++++++++!x]x", "Weed_0"},
    {2, 7.2, 90, .50, "-------------x", "x = f[@.5---------x]+f[@.4+++++++++++!x]@.6x", "Weed"},
    {2, 36, 90, .50, "W", "F = ;W = --FX++FW++FY--;X = +FZ--FY+;Y = ++FZ--FY--FW++;Z = -FX++FW-", "Xmastree_0"},
    {2, 20, 0, .50, "vzfff", "v = [---w][+++w]yv;w = -x[+w]z;x = +w[-x]z;y = yz;z = [+fff][-fff]f", "Pinetree"},
    {2, 60, 90, .50, "r", "w = [+g-f];x = xzf[+wf-x]-wf-y++;y = xzf[-wf-x]+wf-y;z = [-g--f];r = x", "TreeMesh"},
    {2, 60, 90, .50, "r", "x = xf[+f-x]-f-y++;y = xf[-f-x]+f-y;r = x", "SpacefillingTree"},
};



/* Plants, 2/5 */
static lsys plants2 [] = 
{
    /* By Ole Jorgensen */
    {2, 24, 0, .50, "X", "F = FFF;X = +F+F[+X]+F[+X]-F[+X]-F[+X]-F[+X]", "1b"},
    {2, 24, 0, .50, "X", "F = F@.9985F@.9945F;X = +F[-X][+X]+F[-X][+X]+F[-X][+X]-F[-X][+X]-F[-X][+X]-F[-X][+X]", "1bc"},
    {2, 24, 0, .50, "x", "F = FF@.9985F;X = FFF[s][t]FF[s][t]FF[s][t]@.9985FF[s][t]@.9945FF[s][t];s = -F-F[-s][+t]-F[-s][+t]-F[-s][+t]+F[-s][+t]+F[-s][+t]+F[-s][+t];t = +F+F[-s][+t]+F[-s][+t]+F[-s][+t]-F[-s][+t]-F[-s][+t]-F[-s][+t]", "1bc_2"},
    {2, 12, 0, .50, "---X", "F = FFF;X = +F+F[-X][+X]+F[-X][+X]+F[-X][+X]-F[-X][+X]-F[-X][+X]", "1bd"},
    {2, 12, 0, .50, "---x", "F = FF@.9985F;X = FF[s][t]F[s][t]F[s][t]F[s][t]F[s][t];s = -F-F[-s][+t]-F[-s][+t]-F[-s][+t]+F[-s][+t]+F[-s][+t];t = +F+F[-s][+t]+F[-s][+t]+F[-s][+t]-F[-s][+t]-F[-s][+t]", "1bd_2"},
    {2, 12, 0, .50, "X", "F = FFF;X = +F[-X][+X]+@0.95F[-X][+X]+@0.9F[-X][+X]+@0.85F[-X][+X]+@0.8F[-X][+X]+@0.75F[X]", "1be"},
    {2, 12, 0, .50, "X", "F = FFF;X = F[s][t]@0.95F[s][t]@0.9F[s][t]@0.85F[s][t];s = +F[++s][-t]+@0.95F[++s][-t]+@0.9F[++s][-t]+@0.85F[+s][t]+@0.8F[++s][-t]+@0.75F[s];t = -F[+s][--t]-@0.95F[+s][--t]-@0.9F[+s][--t]-@0.85F[s][-t]-@0.8F[-s][--t]-@0.75F[t]", "1be_2"},
    {2, 24, 0, .50, "X", "F = FFFF;X = +F[-X][+X]+F[-X][+X]-F[-X][+X]-F[-X][+X]+F[-X][+X]+F[X]", "1c"},
    {2, 24, 0, .50, "X", "F = FFFFF;X = @.9326F[s][t]@.8557F[s][t]@.7788F[s][t]@.7019F[s][t]@.625F[s][t];s = +F[s][t]+F[s][t]-F[s][t]-F[s][t]+F[s][t]+F[s][t];t = -F[s][t]-F[s][t]+F[s][t]+F[s][t]-F[s][t]-F[s][t]", "1c_2"},
    {2, 24, 0, .50, "x", "f = FFF;x = +F-F+F[---X][+X]-F+F[---X][+X]", "1d"},
    {2, 24, 0, .50, "x", "f = FFFF;x = F[s][t];s = +F[s][t]-F[s][t]+F[s][t]-F[s][t]+F[s][t]-F[s][t];t = -F[s][t]+F[s][t]-F[s][t]+F[s][t]-F[s][t]+F[s][t]", "1d_2"},
    {2, 12, 0, .50, "---X", "F = FFF;X = +F+F[-X][+X]+F[-X][+X]+F[-X][+X]", "1e"},
    {2, 8, 0, .50, "---X", "F = ff;X = @.9F[s][t]@.85F[s][t]@.8F[s][t]@.75F[s][t]@.65F[s][t];s = -@.95F-@.9F[-s][+t]-@.85F[-s][+t]-@.8F[s];t = +@.95F+@.9F[-s][+t]+@.85F[-s][+t]+@.8F[t]", "1e_2"},
    {2, 24, 0, .50, "-----X", "F = FFF;X = +F[+X]-F[+X]+F[-X]-F[-X]-F[+X]+F[+X]", "1i"},
    {2, 24, 180, .50, "|X", "F = FFF;x = F[s][t];s = +F[s][t]-F[s][t]-F[s][t]+F[s][t]-F[s][t]+F[s][t];t = -F[s][t]+F[s][t]+F[s][t]-F[s][t]+F[s][t]-F[s][t]", "1j"},
    {2, 24, 0, .50, "x", "F = FFF;x = F[--Y][++Y]@.9326F[--Y][++Y]@.8557F[--Y][++Y]@.7788F[--Y][++Y]@.7019F[-Y][+Y]@.625F[Y];y = F[--X][++X]@.9326F[--X][++X]@.8557F[--X][++X]@.7788F[--X][++X]@.7019F[-X][+X]@.625F[X]", "2e"},
    {2, 12, 0, .50, "x", "f = FFF;x = @.9326F[s][t]@.8557F[s][t]@.7788F[s][t]@.7619F[s][t]@.725F[s][t];s = +F[s][++t]+@.9326F[s][++t]+@.7788F[s][++t]-@.7619F[s][++t]-@.725F[s][+t]-@.7019F[s];t = -F[--s][t]-@.9326F[--s][t]-@.7788F[--s][t]+@.7619F[--s][t]+@.725F[-s][t]+@.7019F[t]", "2f_2"},
    {2, 12, 90, .50, "------x", "f = FFFF;x = -F[+++X]-F[--X][+++X]+F[--X][+++X]+F[--X][+++X]-F[--X][+++X]-F[--X][+++X]", "2g"},
    {2, 12, 0, .50, "X", "F = ++F[X][++++X]--F[X][++++X];X = --F[----F][F]++F[----F][F]", "Bronchia"},
    {2, 12, 0, .50, "X", "F = +F[+X]-F[-X];X = [-F]+F[-F]+F", "Bronchia2"},
    {2, 24, 0, .50, "x", "f = F[-X][+X]F[-X][+X];x = F-F[-X][+X]F+F[-X][+X]", "Bronchius"},
    {2, 36, 0, .50, "F", "F = F[-s]F[+t];S = -F+F+F-F-F-F+F+F+F+F+F-F-F-F-F-F-F-F-F;T = +F-F-F+F+F+F-F-F-F-F-F+F+F+F+F+F+F+F+F", "CirkularTree"},
    {2, 12, 0, .50, "F", "F = -F[+X]+F[+X];X = +F[+X]+F[+X]", "Feather"},
    {2, 24, 0, .50, "|F", "F = +F[-X]-F[+S];X = -F-F+F-F+F-F+F-F+F-F-F+F-F+F-F+F-F;S = -F-F+F-F+F-F+F-F+F-F-F+F-F+F-F+F-F", "Feather2"},
    {2, 7.2, 0, .50, "x", "f = FFF;x = F[-----X][+++++X]F[----X][++++X]F[---X][+++X]F[--X][++X]F[-X][+X]F[X]", "Fern"},
    {2, 7.2, 0, .50, "x", "f = FFF;x = +F[-----X][+++++X]+F[----X][++++X]+F[---X][+++X]+F[--X][++X]+F[-X][+X]+F[X]", "FernSideView"},
    {2, 12, 0, .50, "X", "f = FFF;x = @.9326F[-l][+r]@.8557F[-l][+r]@.7788F[-l][+r]@.7619F[-l][+r]@.725F[l][r]Fx;r = +F[---r][+r]+@.9326F[---r][+r]+@.9326F[---r][+r]+@.9326F[---r][+r]+@.8557F[--r][r]+@.7788F[-r];l = -F[-l][+++l]-@.9326F[-l][+++l]-@.9026F[-l][+++l]-@.9326F[-l][+++l]-@.8557F[l][++l]-@.7788F[+l]", "Fern2"},
};



/* Plants, 3/5 */
static lsys plants3 [] =
{
    /* By Ole Jorgensen  */
    {2, 24, 0, .50, "x", "F = FFF;x = F[--x][++x]@1.1F[--x][++x]@.9F[-x][+x]@.9F[x]", "Plant01"},
    {2, 7.2, 90, .50, "x", "f = fffff;x = F[s][t]|F[s][t];s = +F+F+FF+FFF[s][t]+FFFFF[s][t]+FFF[s][t]+FF[s][t]+F[s][t]+F;t = -F-F-FF-FFF[s][t]-FFFFF[s][t]-FFF[s][t]-FF[s][t]-F[s][t]-F[s][t]", "Plant02"},
    {2, 7.2, 0, .50, "x", "f = fffff;x = @.95F[s][t];s = +F+F+FF+FFF[s][t]+F[s][t]F[s][t]F[s][t]F[s][t]F[s][t]+@.95F[s][t]@.95F[s][t]@.95F[s][t]+@.95F[s][t]@.95F[s][t]+@.95F[s][t];t = -F-F-FF-FFF[s][t]-F[s][t]F[s][t]F[s][t]F[s][t]F[s][t]-@.95F[s][t]@.95F[s][t]@.95F[s][t]-@.95F[s][t]@.95F[s][t]-@.95F[s][t]", "Plant02B"},
    {2, 24, 90, .50, "--FF", "F = -F[-F]+F[+F-F]F", "Plant03"},
    {2, 24, 90, .50, "--FF", "F = -F[-F]+F[+F-F]", "Plant03_b"},
    {2, 24, 0, .50, "x", "f = ff;x = -F[-x][+x]+F[-x][+x]", "PlantsByRoad"},
    {2, 24, 90, .50, "-----X", "F = FFF;X = +F[+X]-F[-X]+F[+X]+F[+X]", "Plant05"},
    {2, 15.6521739130435, 90, .50, "x", "f = +F[++f]-F[+f];x = -F[++x]++F[+x]", "Plant06"},
    {2, 15.6521739130435, 0, .50, "X", "F = FF;X = F[-X]F[+X]F[-X]F[+X]", "Plant07"},
    {2, 36, 0, .50, "F", "F = F[-X]F[+Y];X = S+T;Y = T-S;S = +F-F+FF-FF+FFF-FFF+FFF+FFFFF-FFFFF+FFFFF-FFFFF+FFFFF;T = -F+F-FF+FF-FFF+FFF-FFF-FFFFF+FFFFF-FFFFF+FFFFF-FFFFF", "Plant08"},
    {2, 12, 0, .50, "F-F-F", "F = F[X];X = FSFT;S = -F[-X]+F[+X];T = +F[+X]-F[-X]", "Plant09"},
    {2, 24, 0, .50, "|++++f", "f = ff[s][t]f[s][t];s = +fff[--s][+t]f[--s][+t]+f[--s][+t]f[--s][+t]f[--s][+t]+f[--s][+s];t = -fff[--s][+t]f[--s][+t]-f[--s][+t]f[--s][+t]f[--s][+t]-f[--s][+t]", "Plant10"},
    {2, 15.6521739130435, 0, .50, "X", "F = +F[-F]-F[+F];X = -F[+X]++F[-X]", "Root"},
    {2, 90, 270, .50, "F-F-F-F", "F = D![-A]D![-B];A = -F+F-FF+FFF-FFFFF;B = +F-F+FF-FFF+FFFFF;D = 42D!\\84D!\\42D", "Sapin"},
    {2, 24, 0, .50, "X", "F = f@0.9975f@0.9935F;X = F[-X][+X]F[-X][+X]F[-X][+X]F[-X][+X]F[-X][+X]F[X]", "Sapin2"},
    {2, 24, 0, .50, "x", "f = f@0.9975f@0.9935F;x = F[+X][-X]F[++X][--X]F[+++X][---X]F[++++X][----X]F[+++++X][-----X]", "Sapin3"},
    {2, 24, 0, .50, "f", "f = F[-X][+X]F;x = +F[-X][+X]-F[-X][+X]", "Seaweed"},
    {2, 24, 0, .50, "f", "f = F[X][y]F;x = ++F[X]--F[X];y = --F[y]++F[y]", "Seaweed02"},
    {2, 12, 0, .50, "f", "f = F[X][y]F;x = ++Fy[X]--Fy[X];y = --Fx[y]++Fx[y]", "Seaweed03"},
    {2, 24, 0, .50, "f", "f = F[X][y]F;x = ++F[X][y]--F[X][y];y = --F[X][y]++F[X][y]", "Seaweed04"},
    {2, 12, 0, .50, "f", "f = F[X][y]F;x = ++F[X][y]--F[X][y];y = --F[X][y]++F[X][y]", "Seaweed05"},
    {2, 16.3636363636364, 0, .50, "F", "F = F[+X]F;X = +F[+X]+F[-X]", "Seaweed06"},
    {2, 32.7272727272727, 0, .50, "F", "F = +F[+X]-FF[-X];X = F[-F]F[+F]F[-F]F[+F]", "Seaweed07"},
    {2, 24, 0, .50, "xy", "f = F[-x][+x][-y][+y]F;x = -F-F[-y][+y]F+F[-y][+y];y = +F+F[-x][+x]F-F[-x][+x]", "Seaweed08"},
    {2, 7.2, 0, .50, "st", "x = @.75f@.85f;s = x[-----s][+++++s]x[----s][++++s]x[---s][+++s]x[--s][++s]x[-s][+s];t = x[-----t][+++++t]x[----t][++++t]x[---t][+++t]x[--t][++t]x[-t][+t]", "Seed"},
    {2, 12, 0, .50, "d", "F = -d[d]+d[d];d = -d[d[|+f][|-f]+d[|++f][|--f]-d[|+++f][|---f]f[|++++f][|----f]]", "Spiralstring"},
    {2, 14.4, 90, .50, "------X", "F = FF;X = -F[++X]+F[--X]-F[++X]+F[--X]", "Symmetree"}
};



/* Plants, 4/5 */
static lsys plants4 [] =
{
    /* By Gary Teachout */
    {2, 10, 90, .50, "---------x", "x = @0.6x@i0.6++++f+@0.5x@i0.5---------f++++@0.6x@i0.6--------------f+++++++++@0.5x@i0.5-----------------f--------------", "Maple1"},
    {2, 10, 90, .50, "---------x", "x = @0.6x@i0.6++f+++@0.5x@i0.5-------f++@0.6x@i0.6----------------f+++++++++++@0.5x@i0.5---------------f----------------", "Maple2"},
    {2, 10, 90, .50, "---------x", "x = -@0.6x@i0.6+++++f+@0.5x@i0.5---------f+++++@0.58!x!@i0.58---------------f++++++++++@0.51!x!@i0.51------------------f--------------", "Maple3"},
    {2, 10, 90, .50, "---------x", "x = -@0.6!x!@i0.6+++++f+@0.45x@i0.45---------f+++++@0.55!x!@i0.55---------------f++++++++++@0.51!x!@i0.51------------------f--------------", "Maple4"},
    {2, 7.5, 90, .50, "--------------fx", "p = q;x = f---------y++++++++f@0.8x@i0.8++++++++++++++++++++++++f-----------------!y!++++++++++++++++++f------------------------;q = @0.35x@i0.35;y = z;z = p", "Fern1"},
    {2, 7.5, 90, .50, "---------------fx", "p = q;x = f---------y++++++++f@0.8x@i0.8+++++++!y!+++++++++++++++++f+f------------------------;q = @0.35x@i0.35;y = z;z = p", "Fern2"},
    {2, 7.5, 90, .50, "---------------fx", "p = q;x = f---------y++++++++f@0.8-x+@i0.8+++++++!y!+++++++++++++++++f+f------------------------;q = @0.35x@i0.35;y = z;z = p", "Fern3"},
    {2, 90, 90, .50, "\\90x", "p = q;x = @0.01d@i0.01\\35p/35@0.04d@i0.04@0.85!x!@i0.85\\180@0.05d@i0.05/180;y = @0.55x@i0.55;q = y", "leaf1"},
    {2, 90, 90, .50, "\\90x", "p = q;a = b;q = y;b = z;r = s;s = t;t = u;u = v;v = w;w = a;x = @0.01d@i0.01\\35p/35/40r\\40@0.04d@i0.04@0.85!x!@i0.85\\180@0.05d@i0.05/180;y = @0.55x@i0.55;z = @0.25x@i0.25", "leaf2"},

    /* By  Jos Torres */
    {2, 8.57142857142857, 0, .50, "X", "X = F[-@.95X][--------@.4Y]-@.95G;Y = F[-@.95Y][--------@.4X]-@.95G", "LEAF"},
    {2, 8.57142857142857, 0, .50, "X", "X = F[-@.95X][++++++++@.4Y]-@.95G;Y = F[-@.95Y][++++++++@.4X]-@.95G", "LEAF_REVERSE"},
    {2, 8.57142857142857, 0, .50, "X", "X = F[-@.95X][++++++++@.4Y]-@.95G-@.95[[--------@.4Y]]-@.9025G;Y = F[-@.95Y][--------@.4X]-@.95G-@.95[[++++++++@.4X]]-@.9025G", "LEAF_DOUBLE"},
    {2, 8.57142857142857, 0, .50, "X", "V = F[-@.95V][++++++++@.4W]-@.95G;W = F[-@.95W];X = F[-@.95X][++++++++@.4Y]-@.95G;Y = F[-@.95Y][++++++++@.4Z]-@.95G;Z = F[-@.95Z][++++++++@.4U]-@.95G;U = F[-@.95U][++++++++@.4V]-@.95G", "LEAF_L6"},
    {2, 8.57142857142857, 0, .50, "X", "V = F[-@.95V][++++++++@.4W]-@.95G;W = F[-@.95W];X = F[-@.95X][++++++++@.4Y]-@.95G;Y = F[-@.95Y][--------@.4Z]-@.95G;Z = F[-@.95Z][++++++++@.4U]-@.95G;U = F[-@.95U][--------@.4V]-@.95G", "LEAF_L6ALTERN"},
    {2, 8.57142857142857, 0, .50, "X", "W = F[-@.95W];X = F[-@.95X][++++++++@.4Y]-@.95G;Y = F[-@.95Y][++++++++@.4Z]-@.95G;Z = F[-@.95Z][++++++++@.4U]-@.95G;U = F[-@.95U][++++++++@.4W]-@.95G", "LEAF_L5"},
    {2, 8.57142857142857, 0, .50, "X", "X = F[-@.95X][++++++++@.4Y]-@.95G;Y = F[-@.95Y][++++++++@.4Z]-@.95G;Z = F[-@.95Z][++++++++@.4U]-@.95G;U = F-@.95U", "LEAF_L4"},
    {2, 8.57142857142857, 0, .50, "X", "X = F[-@.95X][++++++++@.4Y]-@.95G;Y = F[-@.95Y][++++++++@.4U]-@.95G;U = F-@.95U", "LEAF_L3"},

    /* By Ole Jorgensen */
    {2, 12, 90, .50, "F-F-F-F-F-F-F-F-F-F-F-F-F-F-F-F-F-F-F-F-F-F-F-F-F-F-F-F-F-F", "F = F[X];X = FSFT;S = +F[-X]+F[+X];T = -F[+X]-F[-X]", "Flower5"},
    {2, 24, 0, .50, "x", "f = ff@0.9985F;x = F[+X][-X]@0.75F[+X][-X]@0.75F[+X][-X]@0.75F[+X][-X]@0.75F[+X][-X]@0.75F[X]", "Grass"},
    {2, 24, 90, .50, "---x", "f = FFF;x = -F[-X]+F[+X]-F[-X]+F[-X]-F[+X]+F[-X]", "Grass6"},
    {2, 12, 90, .50, "-------F", "F = F[-A]F[++A];A = -F+FFFFF-F+FFF-FF+FF-FFF+F-FFFFF", "Grass2"},
    {2, 24, 180, .50, "-------x", "f = fFFF;x = FF[+X]-F[-X]+F[+X]-F[-X]+F[+X]", "Grass3"},
    {2, 24, 90, .50, "F-F-F-F", "F = D![-A]D[-B];A = FF@0.9F@0.9F@0.9F@0.9F@0.9F@0.9F@0.9F@0.9F@0.9F@0.9F;B = FF@0.9F@0.9F@0.9F@0.9F@0.9F@0.9F@0.9F@0.9F@0.9F@0.9F;D = 42D!\\84D!\\42D", "Orchid"},
    {2, 90, 90, .50, "F-F-F-F-F-F-F-F", "F = D[-A]D[-B];A = -F+F-FF+FFF-FFFFF;B = +F-F+FF-FFF+FFFFF;D = 42D!\\84D!\\42D", "Orchid2"},
    {2, 24, 0, .50, "|x", "f = FFF;x = -F[-X][+X]-F[-X][+X]-F[-X][+X]+F[-X][+X]+F[-X][+X]+F[-X][+X]", "Leaves"},
    {2, 24, 0, .50, "|x", "f = FFF;x = F[--s][++t]@.9326F[-s][+t]@.8557F[s][t]@.7788F[+s];s = -F[s][t]@.9326F[s][t]@.8557F[s][t]@.7788F[s][t]@.7019F[s][t]@.625F[s][t]@.625F[+s];t = +F[s][t]@.9326F[s][t]@.8557F[s][t]@.7788F[s][t]@.7019F[s][t]@.625F[s][t]@.625F[+s]", "Leaves2"},
    {2, 12, 0, .50, "x", "f = FFF;x = -F[--X][+++X]+F[--X][+++X]+@.9326F[--X][+++X]+@.8557F[--X][+++X]+@.7788F[-X][++X]+@.7019F[X]", "Leaves3"},
    {2, 12, 0, .50, "x", "f = FFF;x = F[----s][++++t]@.9326F[---s][+++t]@.8557F[--s][++t]@.7788F[-s][+t];s = -F[--s][+++s]+F[--s][+++s]+@.9326F[--s][+++s]+@.8557F[--s][+++s]+@.7788F[-s][++s]+@.7019F[s][+s];t = +F[---t][++t]-F[---t][++t]-@.9326F[---t][++t]-@.8557F[---t][++t]-@.7788F[--t][+t]-@.7019F[-t][t]", "Leaves4"},

    /* By William McWorter */
    {2, 30, 0, .50, "a", "f = ff;a = f[+a][-a]fa", "Schneider"}
};


static lsys plants5 [] =
{
    /* From the Computational Beauty of Nature */
    {2, 20, 0, .5, "f", "f = %[-f][+f]", "Twig"},
    {2, 25, 0, .65, "f", "f = f[-f]f[+f]f", "Weed 1"},
    {2, 25, 0, .60, "f", "f = %[-f]%[+f]f", "Weed 2"},
    {2, 20, 0, .5, "f", "f = %[-f]%[+f][-f]f", "Weed 3"},
    {2, 25, 0, .65, "f", "f = ff+[+f-f-f]-[-f+f+f]", "Bush 1"},
    {2, 20, 0, .65, "f", "f = %[+f]%[-f]+f", "Bush 2"},
    {2, 20, 0, .6, "f", "f = %[3-f][3+f]%[--f][++f]%f", "Tree 1"},
    {2, 8, 0, .4, "f", "f = %[5+f][7-f]-%[4+f][6-f]-%[3+f][5-f]-%f", "Tree 2"},
    {2, 20, 0, .7, "f", "f = %[--f][+f]-f", "Tree 3"},
    
    /* By Jake Post */
    {2, 45, 90, .71, "--fa++fb++fa--", "f=;a=%a;b=---fa++fb++fa--fa++fb++fa---", "Tree JP"}
};



/* Various tiles */
static lsys tiles [] = 
{
    {2, 15, 90, .50, "X-X-X-X-X-X-X-X-X-X-X-X-X-X-X-X-X-X-X-X-X-X-X-X", "x = [F-F-F-F[+++X+Y]-----F--------F+F+F+F];y = [F-F-F-F[+++Y]-----F--------F+F+F+F]", "CircularTile"},
    {2, 12, 90, .50, "\\84.1A\\96@4.783386117M@I4.783386117/96A", "X = [D\\78D\\46.37236@3.393427D@I3.393427/46.37236D\\114[\\168X\\24Y]D\\78D\\46.37236@3.393427D@I3.393427/46.37236D/78D];Y = [D\\78D\\46.37236@3.393427D@I3.393427/46.37236D/78D\\168[\\192Y]D\\78D\\46.37236@3.393427D@I3.393427/46.37236D];A = X\\12X\\12X\\12X\\12X\\12X\\12X\\12X\\12X\\12X\\12X\\12X\\12X\\12X\\12X\\12Z;Z = [D\\78D\\46.37236@3.393427D@I3.393427/46.37236D\\114D\\78D\\46.37236@3.393427D@I3.393427/46.37236D/78D]", "VoderbergTile"},
    {2, 36, 90, .50, "-WFF++XFF+++YFF++ZFF", "F = ;W = YFF--ZFF++++XFF[+YFF++++WFF]--;X = -YFF++ZFF[+++WFF++XFF]-;Y = +WFF--XFF[---YFF--ZFF]+;Z = ++YFF----WFF[-ZFF----XFF]++XFF", "Penrose1Forced"},
    {2, 36, 90, .50, "WG-XG-WG-XG-WG-XG-WG-XG-WG-X", "F = ;W = [F][--@1.618033989F][--G+++@.618033989G|X+Y|G|W];X = [F---@1.618033989F][--@.618033989GZ|X|+G|W];Y = [-F][@1.618033989F][-G@.618033989|Y-X];Z = [+F][@1.618033989F][@.618033989G++WG|-Z]", "KitesAndDarts"},
    {2, 22.5, 90, .50, "X--X--X--X--|G|X--X--X--X", "X = [FX-----@.7653668647F@I.7653668647[+++++Y]-----F];Y = [F-----@.7653668647F@I.7653668647[+++++Y]-----F]", "SpiralTile"},
    
    /* By William McWorter */
    {2, 30, 90, .50, "f", "f = [+f--g+]-f++g-;g = [+f--g+]-f++g-", "FracRhombusTile"},
    {2, 30, 90, .50, "f", "f = [+f--f+]-f++f-", "RhombusTile"},
    {2, 30, 90, .50, "[u]@q3", "u = [---@iq3f++++@2f]fx;f = ;w = -[+@2@iq3f----@i2f]fz[+++@iq3f----@2f]fy++++[+@2@iq3f----@i2f]fz---;x = ---[+++@iq3f----@2f]fy++++[+@2@iq3f----@i2f]fz[+++@iq3f----@2f]fy-;y = +++[---@iq3f++++@2f]fx----[-@2@iq3f++++@i2f]fw[---@iq3f++++@2f]fx+;z = +[-@2@iq3f++++@i2f]fw[---@iq3f++++@2f]fx----[-@2@iq3f++++@i2f]fw+++", "ThreeTile"},
    {2, 30, 90, .50, "u", "u = [----g-----@1.366f---@q3f-----@2@iq3f]x;f = ;g = ;w = -[++g-----@1.366f---@q3f-----@2@iq3f]zfp[++++g+++++@1.366f+++@q3f+++++@2@iq3f]y++fp++[++g-----@1.366f---@q3f-----@2@iq3f]z---;p = fp;x = ---[++++g+++++@1.366f+++@q3f+++++@2@iq3f]y++fp++[++g-----@1.366f---@q3f-----@2@iq3f]zfp[++++g+++++@1.366f+++@q3f+++++@2@iq3f]y-;y = +++[----g-----@1.366f---@q3f-----@2@iq3f]x--fp--[--g+++++@1.366f+++@q3f+++++@2@iq3f]wfp[----g-----@1.366f---@q3f-----@2@iq3f]x+;z = +[--g+++++@1.366f+++@q3f+++++@2@iq3f]wfp[----g-----@1.366f---@q3f-----@2@iq3f]x--fp--[--g+++++@1.366f+++@q3f+++++@2@iq3f]w+++", "ThreeTilemed"},
    {2, 30, 90, .50, "u+++fp+++v+++fp", "u = [----g-----@1.366f---@q3f-----@2@iq3f]x;f = ;v = [--g+++++@1.366f+++@q3f+++++@2@iq3f]w;g = ;w = -[++g-----@1.366f---@q3f-----@2@iq3f]zfp[++++g+++++@1.366f+++@q3f+++++@2@iq3f]y++fp++[++g-----@1.366f---@q3f-----@2@iq3f]z---;p = fp;x = ---[++++g+++++@1.366f+++@q3f+++++@2@iq3f]y++fp++[++g-----@1.366f---@q3f-----@2@iq3f]zfp[++++g+++++@1.366f+++@q3f+++++@2@iq3f]y-;y = +++[----g-----@1.366f---@q3f-----@2@iq3f]x--fp--[--g+++++@1.366f+++@q3f+++++@2@iq3f]wfp[----g-----@1.366f---@q3f-----@2@iq3f]x+;z = +[--g+++++@1.366f+++@q3f+++++@2@iq3f]wfp[----g-----@1.366f---@q3f-----@2@iq3f]x--fp--[--g+++++@1.366f+++@q3f+++++@2@iq3f]w+++", "ThreeTilemed1"},
    {2, 45, 90, .50, "[z]@q2a", "f = ;x = -[+@q2@i2f--f]fy++[+@q2@i2f--f]fy-;y = +[-@q2@i2f++f]fx--[-@q2@i2f++f]fx+;a = z;z = [-@q2@i2f++f]fx", "TwoTile"},
    {2, 45, 90, .50, "-r", "w = z-f-y;x = z+f+y;y = x+f+w;z = x-f-w;r = x", "2Tile1Med"},
    {2, 60, 90, .50, "r", "f = gg;g = gg;x = fxfff--xff-xff-xff--;r = x", "TrapezoidTile"},
    {2, 90, 90, .50, "r", "f = g;g = gg;x = xff[g-x]-f-f|x|+f-f[+g|x]-ff-;r = x", "TriominoTile"},
    {2, 30, 90, .50, "y", "f = ;x = +fx--fx[----fy]+;y = -fy++fy[++++fx]-", "RhombusTile1"},
    {2, 60, 90, .50, "x", "f = ;x = f+f+f-f-fx--f+f+f-f-fx++f+f+f-f-fx", "Tiling1"}
};



/* Dragon L-systems */
static lsys dragons1 [] = 
{
    {2, 90, 90, .50, "X", "X = X+YF+;Y = -FX-Y", "DragonCurve"},
    
    /* By Dekking */
    {2, 120, 90, .50, "f-f-f", "f = g-f+g;g = f-g+g", "Dekking1err"},
    {2, 120, 90, .50, "g-g-g", "f = g-f+g;g = f-g+f", "Dekking1Improved"},

    /* By Gary Teachout */
    {2, 30, 90, .50, "x", "a = db;b = de;d = ;e = dh;h = dj;j = dk;k = dl;l = dn;n = dx;p = dq;q = dr;r = ds;s = dt;t = du;u = dv;v = dw;w = dy;x = \\66@0.406736da@i0.406736/90@0.913545dy@i0.913545\\24;y = /24@0.913545dx@i0.913545\\90@0.406736dp@i0.406736/66", "dragon_sl_66"},
    {2, 30, 90, .50, "x", "p = dq;a = db;q = dr;b = de;r = dy;d = ;e = dx;x = \\58@0.529919da@i0.529919/90@0.848048dy@i0.848048\\32;y = /32@0.848048dx@i0.848048\\90@0.529919dp@i0.529919/58", "dragon_sl_58"},
    {2, 30, 90, .50, "x", "p = dy;x = \\52@0.615661da@i0.615661/90@0.788010dy@i0.788010\\38;a = dx;y = /38@0.788010dx@i0.788010\\90@0.615661dp@i0.615661/52;d = ", "dragon_sl_52"},
    {2, 30, 90, .50, "x", "p = dy;x = \\38@0.788010dx@i0.788010/90@0.615661dp@i0.615661\\52;a = dx;y = /52@0.615661da@i0.615661\\90@0.788010dy@i0.788010/38;d = ", "dragon_sl_38"},
    {2, 30, 90, .50, "x", "p = dq;a = db;q = dr;b = de;r = dy;d = ;e = dx;x = \\32@0.848048dx@i0.848048/90@0.529919dp@i0.529919\\58;y = /58@0.529919da@i0.529919\\90@0.848048dy@i0.848048/32", "dragon_sl_32"},
   {2, 30, 90, .50, "x", "a = db;b = de;d = ;e = dh;h = dj;j = dk;k = dl;l = dn;n = dx;p = dq;q = dr;r = ds;s = dt;t = du;u = dv;v = dw;w = dy;x = \\25@0.906308dx@i0.906308/90@0.422618dp@i0.422618\\65;y = /65@0.422618da@i0.422618\\90@0.906308dy@i0.906308/25", "dragon_sl_25"},
   {2, 45, 90, .50, "x", "f = ;x = @1.2fx@i1.2++fy;y = fx--@1.2fy@i1.2", "dragon_1"},
    {2, 45, 90, .50, "x", "f = ;x = @0.75fx@i0.75++fy;y = fx--@0.75fy@i0.75", "dragon_0"},
    {2, 45, 90, .50, "x/90x/90x/90x", "a = db;b = de;d = ;e = dh;h = dj;j = dk;k = dl;l = dn;n = dx;p = dq;q = dr;r = ds;s = dt;t = du;u = dv;v = dw;w = dy;x = \\25@0.906308dx@i0.906308/90@0.422618dp@i0.422618\\65;y = /65@0.422618da@i0.422618\\90@0.906308dy@i0.906308/25", "dragon_sl_25-3"},

    /* By William McWorter */
 {2, 60, 90, .50, "r", "f = ;g = ;x = g+g++f-ff+ff-ff+f--g-gx--g+g++f-ff+ff-ff+f--g-gx++g+g++f-ff+ff-ff+f--g-gx;r = g+g++f-ff+ff-ff+f--g-gx", "A"},
    {2, 60, 90, .50, "r", "f = ;g = ;p = fp;x = f+ff-fx-fp-fpf+ff-fxfp+fp+f+ff-fx;r = f+ff-fx-fp-fpf+ff-fx-fp-fpf+ff-fx-fp-fp", "A1"},
    {2, 22.5, 90, .50, "x", "f = ;x = +f--f+x-----f++f-y;y = +f--f+x++++-f++f-y", "Barbells"},
        {2, 32.7272727272727, 90, .50, "x", "f = ;x = [@q2@I2+fx]g[@q2@I2+++fx]", "Alien"},
        {2, 90, 90, .50, "otuz", "o = fo-f+t;p = --f++u-f+x;q = +f-v--f++q;r = +f-zfs;s = fw;t = --f++u;u = --f++y;v = fs;f = ;w = fo-f+p;x = --f++y-f+x;y = +f-r--f++q;z = +f-zfw", "Boundary"},
    {2, 90, 90, .50, "FX", "F = ;X = FX-FX-FXFY+FY+;Y = -FX-FXFY+FY+FY", "Cross"},
    {2, 45, 90, .50, "FX", "F = ;x = +FX--FY+;y = -FX++FY-", "Dragon"},
    {2, 90, 90, .50, "X", "F = ;X = FX-FY;Y = FX+FY", "Dragon_wm"},
    {2, 45, 90, .50, "X", "F = ;X = FX-@.500FZ@2.00-FY;Y = FX+@.500FZ@2.00+FY;Z = FZ", "Dragon1"}
};



/* Dragons 2/2 */
static lsys dragons2 [] =
{
    /* By William McWorter */
    {2, 45, 90, .50, "+X-[---@.5gw+++@q2fz]-y", "F = ;w = gw;X = fx-[---@.5gw+++@q2fz]-fy;g = ;Y = Fx+[+++@.5gw---@q2fz]+fy;z = fz", "DragonAlt"},
    {2, 45, 90, .50, "X", "F = ;X = FX-@.500FZ@2.00-FY;Y = FX+@.500FZ@2.00+FY;Z = FZ", "DragonAlt1"},
    {2, 90, 90, .50, "su", "s = fs-g+x;t = --f++u-g+x;u = --f++u+g-z;f = ;v = fs+g-z;g = ;w = gw-f+t;x = --g++y-f+t;y = --g++y+f-v;z = gw+f-v", "DragonCurd"},
    {2, 45, 90, .50, "X", "F = ;X = FX-@.500FZ@2.00-FY;Y = FX+@.500FZ@2.00+FY;Z = FZ", "Dragonrnd"},
    {2, 90, 90, .50, "fx", "f = ;x = fx-fy;y = fx+fy", "Hiway"},
    {2, 45, 90, .50, "u", "u = v;F = ;v = fX-[---@.5gw+++@q2fz]-fy;w = gw;X = fx-[---@.5gw+++@q2fz]-fy;g = ;Y = Fx+[+++@.5gw---@q2fz]+fy;z = fz", "Hiway1"},
    {2, 90, 90, .50, "s", "s = x-F+t;t = --F++u-F+t;F = ;u = z+F-v;v = Fs+F-v;w = Fsw;x = xy;y = --F++uy;z = zw", "Hiwayint"},
    {2, 22.5, 90, .50, "x", "u = [@.3[---f]g--[---f]g--[---f]g--[---f]g--[---f]g--[---f]g--[---f]g--[---f]g]z;f = ;g = ;w = u;x = [-----f+f+fz]gx----gy;y = [-----f+f+fz]gx++++gy;z = w", "LawnInSpring"},
  {2, 60, 90, .50, "X", "X = X-F-X+F+X", "TerdragnM"},
  {2, 90, 90, .50, "fx-fx", "f = ;g = ;x = fx-gy;y = fx+gy", "TwinDragonCurd1"},
  {2, 90, 90, .50, "fx-fx", "f = ;g = ;x = fx-gy;y = gx+fy", "TwinDragonCurd"},
    {2, 90, 90, .50, "fx", "x = x-yf-fx+yf-fx-yf+fx+yf+fx-yf-fx+yf+fx-yf+fx+yf;y = fx-yf-fx+yf-fx-yf+fx+yf-fx-yf-fx+yf+fx-yf+fx+y", "Dragon0001"},
    {2, 45, 90, .50, "-x", "x = x-f-y-f-x+f+y+f+x-f-y+f+x+f+y;y = x-f-y-f-x+f+y-f-x-f-y+f+x+f+y", "Dragon001med"},
    {2, 90, 90, .50, "r", "x = x-fyf;y = fxf+y;r = fx", "Dragonmed1"},
    {2, 90, 90, .50, "r", "x = x-yf;y = fx+y;r = fx", "Dragon2"},
    {2, 90, 90, .50, "r", "x = x-yf-;y = +fx+y;r = fx", "Dragon1"},
    {2, 45, 90, .50, "-x--x", "x = x--y;y = x+f+y", "Twindragonint"},
	{2, 90, 90, .50, "z", "f = ;g = ;x = ++g-g-@7f@i7-g-g--x-++g+g+@7f@i7+g+g--y;y = ++g-g-@7f@i7-g-g--x+++g+g+@7f@i7+g+g--y;z = x", "Weave"},
    {2, 45, 90, .50, "+X", "X = X-F-Y;Y = X+F+Y", "Hiwaymed"},
    {2, 45, 90, .50, "x", "x = x--y;y = x+f+y", "Hiwayint1"},

    /* New in version 0.65 */
    {2, 90, 90, .50, "xd", "x = xd\\10ryd;y = xd/10lyd;r = \\80;l = /80;d = ", "HeighwayDragon10"}
};



/* Koch related */
static lsys koch [] =
{
    {2, 60, 90, .50, "F++F++F", "F = F-F++F-F", "Koch1"},
    {2, 30, 90, .50, "F+++F+++F+++F", "F = +F---F+++F-", "Koch2"},
    {2, 90, 90, .50, "F+F+F+F", "F = F+F-F-FF+F+F-F", "Koch3"},
    {2, 30, 90, .50, "f----f----f", "f = -f++f--f+", "Koch4"},
    {2, 90, 90, .50, "f-F-F-F", "f = F-F+F+FFF-F-F+F", "Koch5"},
    {2, 90, 90, .50, "f-f-f-f", "f = f+ff-ff-f-f+f+ff-f-f+f+ff+ff-f", "Koch6"},
    {2, 60, 90, .50, "F", "F = F-F++F-F", "Koch Curve"},
    {2, 90, 90, .50, "F+F+F+F+", "F = F-FF+FF+F+F-F-FF+F+F-F-FF-FF+F", "Quad Koch"},
    {2, 60, 90, .50, "f++f++f", "f = f-f++f-f", "Koch Snow Flake"},

    /* By Michael A. Rouse */
    {2, 60, 90, .50, "F", "F = F+F--FF++F-F", "AntiKochCurve101"},
    {2, 60, 90, .50, "F++F++F", "F = F+F--FF++F-F", "AntiKochStar"}
};



/* Space filling curves, 1/2 */
static lsys spacefill1 [] =
{
    {2, 90, 90, .50, "F+F+F+F+", "F = F+FF++F+F", "Curve3"},
    {2, 90, 90, .50, "+l", "R = +LFLF-RFRFR-F-RF+LFL+FR;L = LF-RFR-FL+F+LFLFL+FRFR-", "Fass1"},
    {2, 90, 90, .50, "+l", "R = +LFLFLF-RFR-FL+F+LF-RFR-FLF-RFRF+LFL+FRFR;L = LFLF-RFR-FLFL+FRF+LFL+FR-F-RF+LFL+FRFRFR-", "Fass2"},
    {2, 60, 90, .50, "FL", "F = ;R = -FL+FRFR++FR+FL--FL-FR;L = FL+FR++FR-FL--FLFL-FR+", "FlowSnake"},
    {2, 90, 90, .50, "x", "x = +YF-XFX-FY+;y = -XF+YFY+FX-", "Hilbert"},

    {2, 90, 90, .50, "F+F+F+F", "F = F+F-F-F-F+F+F+F-F", "Peano1"},
    {2, 45, 90, .50, "FXY--F--FXY--F", "X = XY@Q2+F@IQ2+FXY--F--FXY;Y = +@Q2F+@IQ2FXY", "Peano2"},
    {2, 90, 90, .50, "x", "x = XFYFX-F-YFXFY+F+XFYFX;y = YFXFY+F+XFYFX-F-YFXFY", "Peano3"},
    {2, 90, 90, .50, "+Fr", "f = ;r = -FlFl+Fr+Fr-Fl-FlFr-Fl+FrFr+Fl+Fr-FlFrFr+Fl+FrFl-Fl-Fr+Fr+Fl-Fl-FrFr;l = FlFl+Fr+Fr-Fl-Fl+Fr+FrFl-Fr-FlFlFr+Fl-Fr-FlFl-Fr+FlFr+Fr+Fl-Fl-FrFr+", "QuadGosper"},

    {2, 90, 90, .50, "fb", "F = ;H = +;A = FBFA-HFA-FB+FA;J = -;B = FB-FA+FB+JFBFA", "Quartet"},

    /* By William McWorter */
    {2, 90, 90, .50, "z", "f = ;g = ;w = fw;x = +[@I2g-f-@2f-f-f-@I2f]yfw-[@I2g-f-@2f-f-f-@I2f]xfw[@I2g-f-@2f-f-f-@I2f]x-fw[@I2g-f-@2f-f-f-@I2f]y+;y = -[@I2g-f-@2f-f-f-@I2f]xfw+[@I2g-f-@2f-f-f-@I2f]yfw[@I2g-f-@2f-f-f-@I2f]y+fw[@I2g-f-@2f-f-f-@I2f]x-;z = x", "GridMedian"},
    {2, 30, 90, .50, "w", "w = ---x++F++zFx-;x = +++w--F--yFw+;y = -zFx++F++z---;z = +yFw--F--y+++", "Lace"},
    {2, 30, 90, .50, "r", "p = fp;r = s;s = ---fw++fp++fzfpfw-;f = ;w = +++fy--fp--fxfpfy+;x = -fzfpfw++fp++fz---;y = ---fw++fp++fzfpfw-;z = +fxfpfy--fp--fx+++", "PreLaceMed"},
   {2, 30, 90, .50, "r", "w = w-f---z+f+++w+f++f-y--;x = --z-f++f+x+++f+y---f-x;y = ++w+f--f-y---f-x+++f+y;z = z+f+++w-f---z-f--f+x++;r = x", "TrigridMed"},
    {2, 60, 90, .50, "x", "x = x-f-x+f+x+f+x-f-x-f-x+f+x", "Tripeanomed"},
    {2, 120, 90, .50, "f", "f = f-f+f+f-f-f+f", "TriPeano"},
    {2, 36, 90, .50, "w", "f = ;w = --fxfp++fw++fpfy--;p = fp;x = +fz-@.618fp@i.618-fy+;y = ++fzfp--fy--fpfw++;z = -fx+@.618fp@i.618+fw-", "PentiveMed"},

    /* By Michael A. Rouse */
    {2, 60, 90, .50, "s", "y = -;R = z--L+fR+f-R++fR++f-Lf--LfyR;z = +;L = LzfR++fR+f--Lf--L+f-Lf-R++y;s = L", "Hextar"},
    {2, 60, 90, .50, "s", "y = -;R = z--L+fR+f-R++fR++f-Lf--LfyR;z = +;L = LzfR++fR+f--Lf--L+f-Lf-R++y;s = Lf--Lf--Lf", "Hextarb"},

    /* New in version 0.65 */
    {2, 90, 90, .50, "d/90d/90d/90d", "r = \\80;d = d/10ld\\10rd\\10rd\\10rd/10ld/10ld/10ld\\10rd;l = /80", "Peano1_10"},
    {2, 90, 90, .50, "d/90d/90d/90d", "r = \\45;d = d/45ld\\45rd\\45rd\\45rd/45ld/45ld/45ld\\45rd;l = /45", "Peano1_45"},
    {2, 90, 90, .50, "d/90d/90d/90d", "r = \\30;d = d/60ld\\60rd\\60rd\\60rd/60ld/60ld/60ld\\60rd;l = /30", "Peano1_60"},
    {2, 90, 90, .50, "d/90d/90d/90d", "r = \\10;d = d/80ld\\80rd\\80rd\\80rd/80ld/80ld/80ld\\80rd;l = /10", "Peano1_80"}
};



/* Space filling curves, 2/2 */
static lsys spacefill2 [] =
{
    /* By Gary Teachout */
    {2, 45, 90, .50, "-z", "f = ;x = fx+fy+fx-fy-fx-fy-fx-fy-fx+fy+fx+fy+fx+fy+fx-fy-fx;y = fy;z = fx", "Peano_c"},
      {2, 30, 90, .50, "fx", "f = ;x = +f--f+x+f++f-y+++f++f-y-f--f+x---f--f+x+f--f+x---f++f-y++;y = -f--f+x+f++f-y-f++f-y+++f++f-y+++f--f+x---f--f+x---f++f-y", "Hex_7_b"},
    {2, 45, 90, .50, "x", "p = dx;x = \\38!dx!/38dz/52!dp!\\52;z = dz;d = ", "Tri2m_1"},
    {2, 45, 90, .50, "x", "p = dq;x = \\35!dx!/35dz/55!dp!\\55;q = dx;z = dz;d = ", "Tri2m_2"},
    {2, 45, 90, .50, "x", "p = dq;x = dz\\35!dx!/35dz/55!dp!\\55;q = dx;z = dz;d = ", "Tri2m_2_b"},
    {2, 45, 90, .50, "x", "p = dq;x = \\35!dx!/90!dp!\\55;q = dx", "Tri2m_2_c"},
    {2, 45, 90, .50, "x", "p = dq;x = \\32!dx!/32dz/58!dp!\\58;q = dr;z = dz;r = dx;d = ", "Tri2m_3"},
    {2, 30, 90, .50, "x", "f = ;p = --@1.732f@i1.732!p!+fz++fr+++@1.732fz@i1.732----@1.732f@i1.732!q!@1.732fz@i1.732----@1.732f@i1.732!q!++++;x = p;q = ----@1.732f@i1.732!p!++++@1.732fz@i1.732@1.732f@i1.732!p!++++@1.732fz@i1.732---fs--fz-@1.732f@i1.732!q!++;z = fz;r = -----@1.732f@i1.732!p!++++@1.732fz@i1.732@1.732f@i1.732!p!+fz++f!s!++fz+@1.732f@i1.732q-----;s = +++++@1.732f@i1.732p-fz--f!r!--fz-@1.732f@i1.732!q!@1.732fz@i1.732----@1.732f@i1.732!q!+++++", "IsoTrap4a"},
    {2, 30, 90, .50, "-----r", "f = ;p = --@1.732f@i1.732!p!+fz++fr+++@1.732fz@i1.732----@1.732f@i1.732!q!@1.732fz@i1.732----@1.732f@i1.732!q!++++;q = ----@1.732f@i1.732!p!++++@1.732fz@i1.732@1.732f@i1.732!p!++++@1.732fz@i1.732---fs--fz-@1.732f@i1.732!q!++;z = fz;r = -----@1.732f@i1.732!p!++++@1.732fz@i1.732@1.732f@i1.732!p!+fz++f!s!++fz+@1.732f@i1.732q-----;s = +++++@1.732f@i1.732p-fz--f!r!--fz-@1.732f@i1.732!q!@1.732fz@i1.732----@1.732f@i1.732!q!+++++", "IsoTrap4b"},
    {2, 45, 90, .50, "r", "u = +xf--v-@0.707f@i0.707++;v = ++@0.707f@i0.707-u--fy+;x = -uf++y+@0.707f@i0.707--;y = --@0.707f@i0.707+x++fv-;r = x", "Tri_2_d"},
    {2, 45, 90, .50, "r", "u = +fxfz--fv-@0.707fz@i0.707++;f = ;v = ++@0.707fz@i0.707-fu--fzfy+;x = -fufz++fy+@0.707fz@i0.707--;y = --@0.707fz@i0.707+fx++fzfv-;z = fz;r = x", "Tri_2_e"},
    {2, 15, 90, .50, "x", "w = w--f--x+++@q2f@iq2|---x----f----w-----@q2f@iq2---z+++++@q2f@iq2+++w++++++f++y---@q2f@iq2|+++y++++f++++z----;x = ----y++++f++++z|+++@q2f@iq2---z++f++++++x+++@q2f@iq2+++++y---@q2f@iq2-----x----f----w|---@q2f@iq2+++w--f--x;y = ++++x----f----w|---@q2f@iq2+++w--f------y---@q2f@iq2-----x+++@q2f@iq2+++++y++++f++++z|+++@q2f@iq2---z++f++y;z = z++f++y---@q2f@iq2|+++y++++f++++z+++++@q2f@iq2+++w-----@q2f@iq2---z------f--x+++@q2f@iq2|---x----f----w++++", "Tri_99_a"},
    {2, 30, 90, .50, "x", "f = ;p = fp;x = fa-fp---fb+fp+fb+fp--fp+++fa+++fp+fb---fp-fa+++fp+++fa-fp---fb---fp++fp-fa;a = --fy+fp--fp+++fx+++fp+fy---fp-fx;y = fb+fp+++fa-fp-fa-fp++fp---fb---fp-fa+++fp+fb---fp---fb+fp+++fa+++fp--fp+fb;b = ++fx-fp++fp---fy---fp-fx+++fp+fy", "Tri_9_4_f"},
    {2, 30, 90, .50, "r", "f = ;p = fp;x = --fb+fp--fp+++fa+++fp+fb---fp-fa;a = fx-fp---fy+fp+fy+fp--fp+++fx+++fp+fy---fp-fx+++fp+++fx-fp---fy---fp++fp-fx;y = ++fa-fp++fp---fb---fp-fa+++fp+fb;b = fy+fp+++fx-fp-fx-fp++fp---fy---fp-fx+++fp+fy---fp---fy+fp+++fx+++fp--fp+fy;r = x", "Tri_4_9_f"},
    {2, 60, 90, .50, "r", "p = fp;a = ffffffppppppbbb;b = fffpppaa;r = z;f = ;w = ffffppppbb+fp+fpb+fp+fy-fp-fy-fp-fx+fp+fy-fp-fy-fp-fx+fp+fy-fp-fx+fp+fy;x = fpa-fp-fz+fp+fz+fp+fw-fp-fz;y = fpa+fp+fw-fp-fw-fp-fz+fp+fw;z = ffffppppbb-fp-fpb-fp-fx+fp+fx+fp+fy-fp-fx+fp+fx+fp+fy-fp-fx+fp+fy-fp-fx", "Tri_4_9_a"},
    {2, 30, 90, .50, "x", "f = ;p = fp;x = fx-fp---fy+fp+fy+fp--fp+++fx+++fp+fy---fp-fx+++fp+++fx-fp---fy---fp++fp-fx;y = fy+fp+++fx-fp-fx-fp++fp---fy---fp-fx+++fp+fy---fp---fy+fp+++fx+++fp--fp+fy", "Tri_9_f"},
    {2, 60, 90, .50, "x", "f = ;p = fp;x = fp-fp+fx+fp-fp-fy-fp-fx+fp+fy-fp+fp+fx+fp+fy-fp-fx+fp+fy-fp-fx;y = fp+fp-fy-fp+fp+fx+fp+fy-fp-fx+fp-fp-fy-fp-fx+fp+fy-fp-fx+fp+fy", "Tri_9_b"},
    {2, 60, 90, .50, "x", "f = ;w = fffffffppppwww;p = fp;x = ffffwwpp-fp-fw-fp-fx+fp+fx+fp+fy-fp-fx+fp+fx+fp+fy-fp-fx+fp+fy-fp-fx;y = ffffwwpp+fp+fw+fp+fy-fp-fy-fp-fx+fp+fy-fp-fy-fp-fx+fp+fy-fp-fx+fp+fy", "Tri_9_a"},
    {2, 90, 90, .50, "x", "f = ;p = fp;x = -fy+fp+fx-fp-fy+fp+fx-fp-fy+;y = +fx-fp-fy+fp+fx-fp-fy+fp+fx-", "Rect_5"},
    {2, 90, 90, .50, "x", "f = ;w = fz;p = fp;x = -fy+fp+fz-fp-fy+;y = +fx-fp-fz+fp+fx-;z = ffppww", "Rect_2"},
    {2, 90, 90, .50, "x", "f = ;p = fp;x = -fy+fp+fx-fp-fy+;y = +fx-fp-fy+fp+fx-", "Rect_3"},
    {2, 60, 90, .50, "fx", "x = z-f-fx+f+fx+f+fy-f-fx;y = z+f+fy-f-fy-f-fx+f+fy;z = fffzz", "Tri_4_a"},
    {2, 60, 90, .50, "x", "f = ;p = fp;x = fp-fy-fp+fp+fx+fp+fy-fp-fx;y = fy+fp+fx-fp-fy-fp-fp+fx+fp", "Tri_4_b"},
    {2, 90, 90, .50, "x", "f = ;x = fx-fy+fx+fxfy-;y = +fxfy-fy-fx+fy", "Cross5c"},
    {2, 30, 90, .50, "x", "x = xfy--f--x+++f+++y+@1.366f@i1.366---;y = ---@1.366f@i1.366+x+++f+++y--f--xfy", "Tri_4_d"},
    {2, 30, 90, .50, "x", "x = x-f---y+f+++x++@q3f@iq3y--;y = y+f+++x-f---y--@q3f@iq3x++", "Tri_4_e"},
    {2, 30, 90, .50, "x", "f = ;p = fp;x = --fy+fp--fp+++fx+++fp+fy---fp-fx;y = ++fx-fp++fp---fy---fp-fx+++fp+fy", "Tri_4_f"}
};



/* Spirals, all of these are by Jos Torres */
static lsys spirals [] =
{
    {2, 7.82608695652174, 90, .50, "X", "X = XG-@.997X[---FF]", "espiral2"},
    {2, 7.3469387755102, 90, .50, "X", "X = XG-@.98X[+++++++++++FFFFFFF]", "espiral3"},
    {2, 7.3469387755102, 90, .50, "X", "X = XG-@.99X[+++++++++++F-F-F-F-F-F]", "espiral4"},
    {2, 7.3469387755102, 90, .50, "X", "X = XG-@.987X[+++++++++++++F-F-F--F---F----F-----F------F]", "1Nautilus"},
    {2, 7.3469387755102, 90, .50, "X", "X = XG-@.987X[\\120F+F+F+F+F+F/120-F-F-F-------F-F-F]", "2Nautilus"},
    {2, 7.3469387755102, 90, .50, "X", "X = XG-@.9879X[\\120F+F+F+F+F+F/120-F-F-F-------F-F-F]", "3Nautilus"},
    {2, 7.65957446808511, 90, .50, "X", "X = XG-@.97X[@3.68A@.92B];A = ++++++++++++++F+F+F+F+F+@.5F/120-F-F-F;B = \\2--------------FF-FF-FF-FF-FF", "4Nautilus"},
    {2, 7.65957446808511, 90, .50, "X", "X = XG-@.97X[@3.68A@.92B];A = ++++++++++++++F+F+F+F+F+@.5F/120-F-F-F;B = \\2--------------FF-FF-FF-FF-FF", "5Nautilus"},
    {2, 10, 90, .50, "------------[X]------------[X]------------[X]", "X = F[-@.95X][-----@.4Y]-@.95G;Y = F[-@.95Y]", "1SPIRAL"},
    {2, 10, 90, .50, "------------[X]------------[X]------------[X]", "X = F[-@.95X][-----@.6Y]-@.95G;Y = Y-@.95F", "2SPIRAL"},
    {2, 8.57142857142857, 90, .50, "--------------[X]--------------[X]--------------[X]", "X = F[-@.95X][--------@.4Y]-@.95G;Y = F[-@.95Y]", "3SPIRAL"},
    {2, 8.57142857142857, 90, .50, "--------------[X]--------------[X]--------------[X]", "X = F[-@.95X][--------@.4Y]-@.95G;Y = F[-@.95Y][--------@.4Z]-@.95G;Z = F[-@.95X]", "4SPIRALS"}
};


/* By Anthony Hanmer, 1/3 */
static lsys Hanmer_1 [] = 
   {
    {2, 60, 90, .50, "-f", "f = f-f-f-f-f+f+f+f+f", "105d3"},
    {2, 60, 90, .50, "-f", "f = g-f-g-f-g+f+g+f+g", "105d3b"},
    {2, 60, 90, .50, "f+f+f+f+f+f", "f = -f-f-f-f+f+f+f+f", "105d4b"},
    {2, 120, 90, .50, "f", "f = -f-f+f-", "105d5a"},
    {2, 120, 90, .50, "f-f-f", "f = f-ff+ff", "105d5f"},
    {2, 120, 90, .50, "f+f+f", "f = f-ff+ff", "105d5g"},
    {2, 120, 90, .50, "f+f+f", "f = -f-f+f-", "105d5h"},
    {2, 45, 90, .50, "+x", "x = x-f-x-g-x+f+x+g+x", "105m4"},
    {2, 45, 90, .50, "x", "f = ;x = fx-@.5gy@2-fx-@.5gy@2-fx+@.5gy@2+fx+@.5gy@2+fx;y = fy", "105r5"},
    {2, 120, 90, .50, "f-f-f+f-f-f+f-f-f+f", "f = f-h+f-;h = h+f-h+", "109f"},
    {2, 120, 90, .50, "f+f+f-f+f+f-f+f+f-f", "f = f-h+f-;h = h+f-h+", "109g"},
    {2, 90, 90, .50, "f+f+f+f", "f = f+f-f-f+f", "124a"},
    {2, 90, 90, .50, "f+f+f+f", "f = h+h-g-h+h;h = f-f+g+f-f", "124a1"},
    {2, 60, 90, .50, "f+f+f+f+f+f", "f = h++h-g-h++h;h = f--f+g+f--f", "124a2"},
    {2, 90, 90, .50, "f", "f = ff++g-g--ff--g", "125"},
    {2, 90, 90, .50, "f+@.5f+@.5f+@.5f+@.5f+@.5f+@.5f+@.5f+@.5f+@.5f+@.5f+@.5f+@.5f", "f = ff++g-g--ff--g", "125b"},
    {2, 120, 90, .50, "f", "f = -ff+g+g-ff", "127d"},
    {2, 45, 90, .50, "+x", "x = x-f-y+f;y = f-x+f+y", "T129"},
    {2, 120, 90, .50, "f-f-f", "f = f-[@.8f-g]+f", "132b"},
    {2, 45, 90, .50, "f", "f = -f-x++x-f-x--x-f-", "107h2"},
    {2, 45, 90, .50, "f--f--f--f", "f = -f-x++x-f-x--x-f-", "107h2a1"},
    {2, 45, 90, .50, "f+f+f+f+f+f+f+f", "f = -f-x++x-f-x--x-f-", "107h2b"},
    {2, 45, 90, .50, "ff++++ff--ff++++ff--ff++++ff--ff++++ff", "f = -f-x++x-f-x--x-f-", "107h2c"},
    {2, 90, 90, .50, "d\\90d\\90d\\90d", "d = ddd\\88dd\\88dd/176dd\\88dd/176dd\\88dd/176dd\\88dd\\88ddd", "155i3a"},
    {2, 90, 90, .50, "f-f-f-f", "f = -fff-ff-f-f+f+ff+fff+", "105c1"},
    {2, 90, 90, .50, "f-f-f-f", "f = -fff-ffff-ff-f-f+f+ff+ffff+fff", "104b"},
    {2, 45, 90, .50, "f", "f = f-f-f++f-f-f", "107h2c"},
    {2, 45, 90, .50, "f++f++f++f", "f = f-f-f++f-f-f", "107h2c2"},
    {2, 45, 90, .50, "f--f--f--f", "f = -fx++x-fx--x-f-", "107h7"},
    {2, 45, 90, .50, "f----f", "f = -f-x++x-f-x--x-f-", "107h9"}
   };

/* By Anthony Hanmer, 2/3 */
static lsys Hanmer_2 [] =
  {
    {2, 45, 90, .50, "f--f--f--f", "f = f+f++++g+f-f++++g-f", "138c"},
    {2, 90, 90, .50, "f", "f = ff++g-ff++g", "139"},
    {2, 45, 90, .50, "f++f++f++f", "f = -f--x++x-f--x--x-f-", "107h17b"},
    {2, 45, 90, .50, "f--f--f--f", "f = -f-x++x-g-x--x-f-g", "107h19"},
    {2, 45, 90, .50, "fh--fh--fh--fh", "f = +f++x--x+f++x++x+x;h = -f--x++x-f--x--x-x", "107h21"},
    {2, 45, 90, .50, "f-------f+f-------f+f-------f+f-------f+f", "f = -x--f++f-x--f--f", "107h22b"},
    {2, 45, 90, .50, "f++++f++++f++++f++++f++++f++++f++++f", "f = x--f+f--x--f--f", "107h22d2"},
    {2, 45, 90, .50, "f++++f++++f++++f", "f = x-f+f--x--f--f", "107h22e"},
    {2, 90, 90, .50, "f-f-f-f", "f = f+f+f-f--f+f+f-f", "173a"},
    {2, 90, 90, .50, "f-f-f-f", "f = f-f--f+f+f", "173b"},
    {2, 90, 90, .50, "f-f-f-f", "f = f-f+f+f--f+f+f-f", "173c"},
    {2, 90, 90, .50, "f-f-f-f--f+f+f+f", "f = f-f+@.5f+@2f-f", "177"},
    {2, 120, 90, .50, "f-f-f", "f = f-f-ff+x-f-x", "180a"},
    {2, 90, 90, .50, "f++f++f++f", "f = f-ff+f-f+ff+f", "119z1"},
    {2, 90, 90, .50, "f+f+f+f", "f = f--ff+f-g+ff+f", "119zl"},
    {2, 90, 90, .50, "ff++ff-ff++ff-ff++ff-ff++ff", "f = ff--f-", "107h2c"},
    {2, 45, 90, .50, "-f----f", "f = f-f-ff----f--f----f--f-f-f", "233a"},
    {2, 45, 90, .50, "f--f--f--f----f++f++f++f", "f = f-f--f--f--f-ff", "253a"},
    {2, 60, 90, .50, "f--f--f---f++f++f", "f = ff--f--f--fff", "258a"},
    {2, 45, 90, .50, "f--f--f--f----f++f++f++f", "f = f---f----f---f----f---f----f---ff", "264b"},
    {2, 45, 90, .50, "f--f--f--f----f++f++f++f", "f = f---ff----ff---f----f---ff----ff---ff", "265b"},
    {2, 45, 90, .50, "f++f++f++f", "f = f-f--f----f++f---f", "286b"},
    {2, 90, 90, .50, "-f--f", "f = f-ff+ff--ff-ff-fff", "293a"},
    {2, 60, 90, .50, "f-f-f-f-f-f", "f = f-ff--f--@.8f---f++@1.25f++ff--ff", "388a"},
    {2, 22.5, 90, .50, "f----f----f----f--------f++++f++++f++++f", "f = ---f--f--------f++f-----fff", "397b"},
    {2, 45, 90, .50, "--f----f", "f = f-ff----ff---f---ff----ff-f", "403a"},
    {2, 120, 90, .50, "f+f+f", "f = f-fg+f-g+ff+f", "120c"},
    {2, 60, 90, .50, "\\60d/180d", "d = d\\60d\\58d/178d\\58d/178d\\60d\\120dd", "484a"},
    {2, 60, 90, .50, "f--f--f", "f = f-f-@.5f---f-f---f-@2f--ff", "502b"},
    {2, 60, 90, .50, "f--f--f---f++f++f", "f = f--f-@.5f---f-f---f-@2f-ff", "505c"},
    {2, 60, 90, .50, "f--f--f---f++f++f", "f = --f-@.5f---f-f---f-@2f-ff", "508c"}

  };

/* By Anthony Hanmer, 3/3 */
static lsys Hanmer_3 [] =
  {
    {2, 60, 90, .50, "f--f--f", "f = f-f---f--f", "271a"},
    {2, 45, 90, .50, "f--f--f--f", "f = f-f--f--f--ff++f++f++f+ff", "T184a"},
    {2, 90, 90, .50, "f-f-f-f", "f = f-f--ff--f+ff", "T196a"},
    {2, 120, 90, .50, "f-f-f", "f = f-ff+f+f+ff+f", "120r"},
    {2, 120, 90, .50, "f+f+f", "f = fg+f-gf+", "120zd"},
    {2, 120, 90, .50, "f+f+f", "f = f+gg+f-g+gg+f", "120zh"},
    {2, 120, 90, .50, "f+f+f", "f = g+fg+g+gg+f", "120zj"},
    {2, 120, 90, .50, "f-f-f", "f = g+ff+g-f+ff+g", "120zp"},
    {2, 60, 90, .50, "f--f--f", "f = ff--f--f-f--f+f", "T200a"},
    {2, 45, 90, .50, "--f----f", "f = f-ff----ff---f---ff----ff-f", "403a"},
  
    {2, 45, 90, .50, "f--f--f--f----f++f++f++f", "f = -ff+++f----f---f---ff", "419c"},
    {2, 120, 90, .50, "f+f+f", "f = g+ff+g-g+ff+g", "120zt"},
    {2, 120, 90, .50, "f-f-f", "f = f+fg-f-f-gf+f", "120zze"},
    {2, 120, 90, .50, "f+f+f", "f = -ff+f+f+ff+f", "120zzj"},
    {2, 72, 90, .50, "f+f+f+f+f", "f = g-ff+g-g+ff+g", "121m"},
    {2, 72, 90, .50, "f+f+f+f+f", "f = f-gg+f-f+gg+f", "121n"},
    {2, 45, 90, .50, "-f----f", "f = f--f---f---f----f+++f+++f--ff", "518a"},
    {2, 45, 90, .50, "-x", "f = ff;x = x[@iq2f@q2x][+ff---x][-ff+++x]", "triangled"},
    {2, 72, 90, .50, "-X", "X = f[@.9fx]+[@.1fx]+[@.9fx]-[@.9fx]+[@.1fx]+[@.9fx]-[@.9fx]+[@.1fx]+[@.9fx]-[@.9fx]+[@.1fx]+[@.9fx]", "16a"},
    {2, 10, 90, .50, "---------X", "X = f[@.5fx]+[@.4fx]+[@.5fx]g[@.5fx]+[@.4fx]+[@.5fx]g[@.5fx]+[@.4fx]+[@.5fx]g[@.5fx]+[@.4fx]+[@.5fx]g[@.5fx]+[@.4fx]+[@.5fx]g[@.5fx]+[@.4fx]+[@.5fx]", "28s"},
  
    {2, 90, 90, .50, "x+x+x+x", "x = fx+x--x+x", "68"},
   
    {2, 60, 90, .50, "xx+xx+xx+xx+xx+xx", "x = fx+x--x-x+x+x", "70c"},
  
    {2, 90, 90, .50, "xy+xy+xy+xy", "x = +fyx-gxfy;y = -fxy+gyfx", "99h"},
    {2, 45, 90, .50, "x--u--", "u = fu-@.5fw@2-fv;v = fu+@.5fw@2+fv;f = ;w = fw;x = fx-@.5fz@2-fy;y = fx+@.5fz@2+fy;z = fz", "DragR2c"},
  
    {2, 45, 90, .50, "+x", "x = x-f-x-f-x+f+x+f+x", "105m"},
   
    {2, 72, 90, .50, "f-f-f-f-f", "f = f-[f-g]+f", "121zzn"},
   
    {2, 60, 90, .50, "f+f+f", "f = f-gg+f-f+ff+f", "122l"},
    {2, 60, 90, .50, "f-f-f-f-f-f", "f = +ff+f-f+ff+f", "122w"},
   
    {2, 60, 90, .50, "f-f-f-f-f-f", "f = f-[gg+f-f]+f+g-", "122zzl"},
    {2, 45, 90, .50, "f+f+f+f", "f = +fg++f-g+fg--f", "123zzf"},
    {2, 45, 90, .50, "f-f-f-f-f-f-f-f", "f = f-[f-g]+f", "123zzn"},
    {2, 45, 90, .50, "f--f--f--f", "f = f-[@.9f-g]+f", "123zzn1"}
};


static struct
{
  char * group_name;
  lsys * l;
  int size;
} builtins [] =
  {
      {"Fractint - 1", fractint1, countof(fractint1)},
      {"Fractint - 2", fractint2, countof(fractint2)},
      {"Cesaros - 1", cesaros1, countof(cesaros1)},
      {"Cesaros - 2", cesaros2, countof(cesaros2)},
      {"Dragons - 1", dragons1, countof(dragons1)},
      {"Dragons - 2", dragons2, countof(dragons2)},
      {"Koch", koch, countof(koch)},
      {"Curves", curves, countof(curves)},
      {"Curves - Space Filling - 1", spacefill1, countof(spacefill1)},
      {"Curves - Space Filling - 2", spacefill2, countof(spacefill2)},
      {"Tiles", tiles, countof(tiles)},
      {"Spirals", spirals, countof(spirals)},
      {"Gaskets", gaskets, countof(gaskets)},
      {"Plants - Square", sqplants, countof(sqplants)},
      {"Plants - 1", plants1, countof(plants1)},
      {"Plants - 2", plants2, countof(plants2)},
      {"Plants - 3", plants3, countof(plants3)},
      {"Plants - 4", plants4, countof(plants4)},
      {"Plants - 5", plants5, countof(plants5)},
      {"Misc - 1", misc1, countof(misc1)},
      {"Misc - 2", misc2, countof(misc2)},

      /* New in version 0.65 */
      {"Hanmer - 1", Hanmer_1, countof(Hanmer_1)},
      {"Hanmer - 2", Hanmer_2, countof(Hanmer_2)},
      {"Hanmer - 3", Hanmer_3, countof(Hanmer_3)}
};
#endif /* BUILTIN_H */
