/* colors.h
 *
 * Copyright (C) 2002 Ron Coscorrosa
 *
 * This software is released under the terms of the GNU General Public License
 * (GNU GPL), see the file COPYING for details.
 *
 */

#ifndef COLORS_H
#define COLORS_H

#include <gtk/gtk.h>

#include "hsv.h"
#include "constants.h"

typedef struct { double r, g, b; } dcolor;
typedef enum { MAP, FMAP } map_type;
typedef struct
{
    char * name;
    GList * colors;
    int loop;
    map_type type;
} color_group;


typedef enum {COLOR_RANDOM, COLOR_UNIFORM, COLOR_SMOOTH, COLOR_CUSTOM} color_type;

extern int get_colors (GdkColor * colors, int ncolors, color_type method, int index);
extern void make_color_path_rgb (color_group * g, GdkColor * colors, int *ncolorsP);


/* The following functions are taken from the excellent XScreenSaver package:
   xscreensaver, Copyright (c) 1991-2002 Jamie Zawinski <jwz@jwz.org>

   You can get the latest version at: http://www.jwz.org/xscreensaver/

   The changes between these versions and the orignals are:
   1) Make it work with GdkColor et. al. vs. XColor
   2) No writable/allocate arguments, we use the GdkRGB colormap which takes
      care of the allocating part automagically.  We don't support writable 
      colors here either (the color changing routines in GDK 1.2 are deprecated
      in 2.0, and I can't find replacements).  Even so, doing them in GTK/GDK
      would be a huge PITA.
   3) The random() calls were changed to GLIB equivalents
*/


/* Generates a sequence of colors evenly spaced between the given pair
   of HSV coordinates.

   If closed_p is true, the colors will go from the first point to the
   second then back to the first.
 */
extern void make_color_ramp (int h1, double s1, double v1,
			     int h2, double s2, double v2,
			     GdkColor *colors, int *ncolorsP,
			     gboolean closed_p);

/* Generates a sequence of colors evenly spaced around the triangle
   indicated by the thee HSV coordinates.
 */
extern void make_color_loop (int h1, double s1, double v1,
			     int h2, double s2, double v2,
			     int h3, double s3, double v3,
			     GdkColor *colors, int *ncolorsP);


/* Allocates a hopefully-interesting colormap, which will be a closed loop
   without any sudden transitions.
 */
extern void make_smooth_colormap (GdkColor *colors, int *ncolorsP);

/* Allocates a uniform colormap which touches each hue of the spectrum,
   evenly spaced.  The saturation and intensity are chosen randomly, but
   will be high enough to be visible.
 */
extern void make_uniform_colormap (GdkColor *colors, int *ncolorsP);

/* Allocates a random colormap (the colors are unrelated to one another.)
   If `bright_p' is false, the colors will be completely random; if it is
   true, all of the colors will be bright enough to see on a black background.
 */
extern void make_random_colormap (GdkColor *colors, int *ncolorsP,
				  gboolean bright_p);


extern void make_color_path (int npoints, int *h, double *s, double *v,
			     GdkColor *colors, int *ncolorsP);
#endif /* COLORS_H */

