/* constants.h 
 *
 * Copyright (C) 2002 Ron Coscorrosa
 *
 * This software is released under the terms of the GNU General Public License
 * (GNU GPL), see the file COPYING for details.
 *
 */

#ifndef CONSTANTS_H
#define CONSTANTS_H

#include <gtk/gtk.h>

#define TITLE "L-system Explorer"
#define URL "http://www.cs.pdx.edu/~coscorrr/programs/lsysexp/"
#define OPTIONS_NAME "options"
#define CUSTOM_NAME  "lsyscustom"

/* Note: suggest keeping this here otherwise some L-systems will start using
 * numbers which overflow */
#define MAXLEVELSIZE 50

/* Color stuff, anything > than 256 colors is probably overkill for these
 * (it's not like a mandelbrot, we're just drawing a bunch of lines) */
#define MAXCOLORS 512
#define MINCOLORS 16
#define DEFAULT_COLORS 256
#define MAXPOINTS (MAXCOLORS * 2)

/* User options */
typedef struct _opts
{
   int width, height, ncolors;
    GdkColor bgcolor;
   char *save_dir;
    int center_window;
} opts;

/* Various paths */
typedef struct
{
    char *lsysexp_dir, *maps_dir, *options_file, *custom_file;
    const char *lsysexp_url;
} path_info;

/* One of these per L-system */
typedef struct _lsys
{
    int level;
    double da, a0, ds;
    char *axiom, *rule, *descrip;
} lsys;

/* One of these per each L-system group (the builtin groups are in builtin.h,
   and users can add/save their own groups */
typedef struct _lsys_group
{
    char * group_name;
    GList * lsys_head;
} lsys_group;

#endif /* CONSTANTS_H */

