/* dialog_ui.c
 *
 * Copyright (C) 2002 Ron Coscorrosa
 *
 * This software is released under the terms of the GNU General Public License
 * (GNU GPL), see the file COPYING for details.
 *
 * Create interface for commonly used dialogs
 */

#include "dialog_ui.h"
#include "dialog_cb.h"
#include "util.h"
#include "lsys.h"
#include "config.h"

extern path_info paths;

/* Create a simple error message modal dialog box with a message and 
 * an OK button */
void
ok_dialog(const char * title, char * msg, GtkWindow * parent)
{
    GtkWidget *align;
    GtkWidget * dialog = gtk_dialog_new_with_buttons 
	(title,
	 parent,
	 GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
	 GTK_STOCK_OK,
	 GTK_RESPONSE_NONE,
	 NULL);
    g_signal_connect (G_OBJECT (dialog), 
			      "response", 
			      G_CALLBACK (gtk_widget_destroy),
			      G_OBJECT (dialog));

    align = stock_image_label (GTK_STOCK_DIALOG_ERROR, msg,
			      GTK_ICON_SIZE_DIALOG, 8, TRUE);

    gtk_container_set_border_width (GTK_CONTAINER(align), 8);
    gtk_container_add (GTK_CONTAINER (GTK_DIALOG(dialog)->vbox),
		       align);
    gtk_widget_show_all (dialog);
}



/* Create a modal question yes/no dialog */
GtkWidget*
yes_no_dialog (const char * title, char * msg,
			   GtkWindow * parent)
{
    GtkWidget *align;
    GtkWidget * dialog = gtk_dialog_new_with_buttons 
	(title,
	 parent,
	 GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
	 GTK_STOCK_OK,
	 GTK_RESPONSE_ACCEPT,
	 GTK_STOCK_CANCEL,
	 GTK_RESPONSE_REJECT,
	 NULL);

    align = stock_image_label (GTK_STOCK_DIALOG_QUESTION, msg,
			      GTK_ICON_SIZE_DIALOG, 8, TRUE);

    gtk_container_set_border_width (GTK_CONTAINER(align), 8);
    gtk_container_add (GTK_CONTAINER (GTK_DIALOG(dialog)->vbox), align);
    gtk_widget_show_all (dialog);
    return dialog;
}



/* Create the Help/About... Window */
void
create_about_window (GtkWindow *win)
{
    GtkWidget *dialog, *url_label, *eventbox, *button;
    GdkCursor *cursor;
    
    char *url_color = g_strdup_printf("<span foreground=\"blue\" underline=\"single\">%s</span>", paths.lsysexp_url);

    char *version = g_strdup_printf("L-System Explorer, version %s", VERSION);
    
    cursor = gdk_cursor_new (GDK_HAND2);

    dialog = gtk_dialog_new_with_buttons
	("About L-system Explorer",
	 GTK_WINDOW(win),
	 GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
	 NULL);

    g_signal_connect  (G_OBJECT (dialog),
		       "response",
		       G_CALLBACK (gtk_widget_destroy),
		       G_OBJECT (dialog));

    gtk_container_add (GTK_CONTAINER (GTK_DIALOG(dialog)->vbox), 
		       label_align_pad (version, 0.5, 0.5, 8, 8));

    gtk_container_add (GTK_CONTAINER (GTK_DIALOG(dialog)->vbox),
		       label_align_pad ("Copyright (C) 2002 Ron Coscorrosa <coscorrr@cs.pdx.edu>", 0.5, 0.5, 8, 8));

    /* Create a button to launch URL of L-system Explorer */
    eventbox = gtk_event_box_new();
    button = gtk_button_new();
    gtk_button_set_relief (GTK_BUTTON (button), GTK_RELIEF_NONE);
    url_label = gtk_label_new(NULL);
    gtk_label_set_markup (GTK_LABEL(url_label), url_color);
    gtk_container_add (GTK_CONTAINER (button), url_label);
    gtk_container_add (GTK_CONTAINER (eventbox), button);
    gtk_container_add (GTK_CONTAINER (GTK_DIALOG(dialog)->vbox), eventbox);
    g_signal_connect (G_OBJECT (button), "clicked",
		      G_CALLBACK (on_about_url_clicked), dialog);

    gtk_container_add (GTK_CONTAINER (GTK_DIALOG(dialog)->vbox), 
		       label_align_pad ("Released under the terms of the GNU GPL",
					0.5, 0.5, 8, 8));

    /* Add OK button and set its focus (so URL button doesn't have it) */
    button = gtk_dialog_add_button(GTK_DIALOG(dialog),
				   GTK_STOCK_OK,
				   GTK_RESPONSE_NONE);
    GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
    gtk_widget_grab_focus (button);

    gtk_widget_show_all (dialog);
    gdk_window_set_cursor (eventbox->window, cursor);

    g_free (version);
    g_free (url_color);
}

