/* lsyswin_ui.h 
 *
 * Copyright (C) 2002 Ron Coscorrosa
 *
 * This software is released under the terms of the GNU General Public License
 * (GNU GPL), see the file COPYING for details.
 *
 */

#ifndef LSYSWIN_UI_H
#define LSYSWIN_UI_H

#include <gtk/gtk.h>
#include "mainwin_ui.h"
#include "constants.h"

typedef struct _lsys_color
{
    GdkColor *colors;
    GdkColor bgcolor;
    GdkColor fgcolor;
    int colors_size;
    int ncolors;
    double color_index;
} lsys_color;

/* Each level for each lsys_draw has one of these, which we need to calculate 
   the window size so that the thing will fit */
typedef struct _level_info
{
    char used;            /* cache flag */
    double minx, miny;    /* upper left corner */
    double maxx, maxy;
    double scale, xo, yo; /* scale, offsets */
    int seed;             /* for -noise */
    guint32 line_count;   /* number of line segments at this level */
    double color_increment;
} level_info;

/* Keeps track of our current position */
typedef struct _position
{
    double x, y, a, s;
    double explicit_a;
    int reverse;
} position;

typedef enum {MODE_LINES, MODE_POINTS, MODE_RANDOM} drawmode;

typedef struct
{
    /* widgets used to create the lsystem window */
    GtkWidget *win;
    GtkWidget *menu_bar;
    GtkTooltips * tooltips;
    GtkAccelGroup *accel_group;
    GtkWidget *drawing_area;
    GtkWidget *s_border, *s_noise, *s_level;
    main_window *main_win;

    /* data associated with each lsystem window */
    int level;
    double da, a0, ds, noise;
    char * axiom;
    char * rules ['z' - 'a' + 1];  /* rules[x-'a'] = "x = ..." */
    char * rule_string;

    level_info levels[MAXLEVELSIZE];
    GdkPixmap * pixmap;
    GdkGC * gc;
    guint width, height, dim, border;
    lsys_color color;
    position pos;
    drawmode mode;
} lsys_window;

extern lsys_window * create_lsys_window(main_window * win);
extern void create_lsys_window_menubar (lsys_window * win);

#endif /* LSYSWIN_UI_H */

