/* main.c
 *
 * Copyright (C) 2002 Ron Coscorrosa
 *
 * This software is released under the terms of the GNU General Public License
 * (GNU GPL), see the file COPYING for details.
 *
 */

#include "config.h"

/* For mkdir(2), and unlink */
#include <sys/stat.h>
#include <sys/types.h>
#include <errno.h>
#include <unistd.h>

#ifdef WINDOWS
   #define mkdir(a,b) mkdir(a)
#endif /* WINDOWS */

#include "lsys.h"
#include "mainwin_ui.h"
#include "color_map.h"
#include "constants.h"

/* Globals */
opts options;
path_info paths;
GList *groups = NULL, *color_map_list = NULL;
char stubs [('z' - 'a' + 1) * 2];
GRand * RNG;



int
main (int argc, char *argv[])
{
    int i;
    main_window * win;
    
    /* Used to make L-system rules reflexive by default (a=a, b=b, etc.) */
    for (i = 0; i < 'z' - 'a' + 1; ++i)
    {
	stubs[2 * i] = 'a' + i;
	stubs[2 * i + 1] = 0;
    }
    
    paths.lsysexp_dir = g_strdup_printf("%s/.lsysexp", g_get_home_dir());
    paths.custom_file = g_strdup_printf("%s/%s", paths.lsysexp_dir, CUSTOM_NAME);
    paths.maps_dir = g_strdup_printf ("%s/maps", paths.lsysexp_dir);
    paths.options_file = g_strdup_printf("%s/%s", paths.lsysexp_dir, OPTIONS_NAME);
    paths.lsysexp_url = URL;

    /* Version 0.50 used ~/.lsysexp as a file, if they have that, then we
     * need to:
     * 1) Read in contents of ~/.lsysexp, and delete ~/.lsysexp
     * 2) create ~/.lsysexp as a directory
     * 3) move original ~/.lsysexp contents to file ~/.lsysexp/lsyscustom
     */
    if (! g_file_test (paths.lsysexp_dir, G_FILE_TEST_IS_DIR)
	&& g_file_test (paths.lsysexp_dir, G_FILE_TEST_EXISTS))
    {
	int size;
	char * orig_file = NULL;
	if (! g_file_get_contents (paths.lsysexp_dir, &orig_file, &size, NULL))
	{
	    fprintf (stderr, "Unable to read from: %s\n", paths.lsysexp_dir);
	    fprintf (stderr, "And copy it to: %s\n", paths.custom_file);
	}
	else
	{
	    if (unlink (paths.lsysexp_dir))
		perror ("unlink");
	    else
	    {
		if (mkdir (paths.lsysexp_dir, 0777))
		    fprintf (stderr,
			     "Unable to create L-system Explorer user directory: %s\n",
			     paths.lsysexp_dir); 
		else
		{
		    /* Assuming I can write the file if I can make the dir */
		    FILE * out = fopen (paths.custom_file, "w");
		    fputs (orig_file, out);
		    fclose (out);
		}
	    }
	    g_free (orig_file);
	} 
    }

    /* Create ~/.lsysexp if it doesn't exist */
    else if (! g_file_test (paths.lsysexp_dir, G_FILE_TEST_EXISTS))
    {
	if (mkdir (paths.lsysexp_dir, 0777))
	{
	    fprintf (stderr, "Unable to create L-system Explorer user directory: %s\n", paths.lsysexp_dir);
	}
    }

    if (! g_file_test (paths.maps_dir, G_FILE_TEST_EXISTS))
    {
	if (mkdir (paths.maps_dir, 0777))
	{
	    fprintf (stderr, "Unable to create L-system Explorer user color maps directory: %s\n", paths.maps_dir);
	}
    }
   
    RNG = g_rand_new ();
    load_color_maps (&color_map_list);

    gtk_init (&argc, &argv);

    win = create_main_window();
    gtk_widget_show_all (win->win);
    
    gtk_main ();

    destroy_color_maps (&color_map_list);
    destroy_lsystems();
    
    if (options.save_dir) g_free (options.save_dir);
    g_free (paths.lsysexp_dir);
    g_free (paths.maps_dir);
    g_free (paths.custom_file);
    g_free (paths.options_file);
    g_rand_free(RNG);

    return 0;
}

